@@ -59,7 +59,10 @@ class CatalogServiceClientMeta(type):
     _transport_registry["grpc"] = CatalogServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = CatalogServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[CatalogServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[CatalogServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -164,10 +167,18 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def branch_path(project: str, location: str, catalog: str, branch: str,) -> str:
+    def branch_path(
+        project: str,
+        location: str,
+        catalog: str,
+        branch: str,
+    ) -> str:
         """Returns a fully-qualified branch string."""
         return "projects/{project}/locations/{location}/catalogs/{catalog}/branches/{branch}".format(
-            project=project, location=location, catalog=catalog, branch=branch,
+            project=project,
+            location=location,
+            catalog=catalog,
+            branch=branch,
         )
 
     @staticmethod
@@ -180,10 +191,16 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def catalog_path(project: str, location: str, catalog: str,) -> str:
+    def catalog_path(
+        project: str,
+        location: str,
+        catalog: str,
+    ) -> str:
         """Returns a fully-qualified catalog string."""
         return "projects/{project}/locations/{location}/catalogs/{catalog}".format(
-            project=project, location=location, catalog=catalog,
+            project=project,
+            location=location,
+            catalog=catalog,
         )
 
     @staticmethod
@@ -196,7 +213,9 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -209,9 +228,13 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -220,9 +243,13 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -231,9 +258,13 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -242,10 +273,14 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -517,12 +552,20 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListCatalogsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -639,7 +682,12 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -689,11 +737,6 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         -  UserEventService will only join events with products from
            branch {newBranch}.
 
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
-
 
         .. code-block:: python
 
@@ -760,7 +803,10 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def get_default_branch(
@@ -776,11 +822,6 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         [CatalogService.SetDefaultBranch][google.cloud.retail.v2.CatalogService.SetDefaultBranch]
         method under a specified parent catalog.
 
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
-
 
         .. code-block:: python
 
@@ -855,7 +896,12 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -876,7 +922,9 @@ class CatalogServiceClient(metaclass=CatalogServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-retail",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-retail",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
