@@ -226,8 +226,7 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -327,11 +326,6 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         -  UserEventService will only join events with products from
            branch {newBranch}.
 
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
-
         Returns:
             Callable[[~.SetDefaultBranchRequest],
                     ~.Empty]:
@@ -363,11 +357,6 @@ class CatalogServiceGrpcTransport(CatalogServiceTransport):
         [CatalogService.SetDefaultBranch][google.cloud.retail.v2.CatalogService.SetDefaultBranch]
         method under a specified parent catalog.
 
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
-
         Returns:
             Callable[[~.GetDefaultBranchRequest],
                     ~.GetDefaultBranchResponse]:
