@@ -334,11 +334,6 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
         -  UserEventService will only join events with products from
            branch {newBranch}.
 
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
-
         Returns:
             Callable[[~.SetDefaultBranchRequest],
                     Awaitable[~.Empty]]:
@@ -370,11 +365,6 @@ class CatalogServiceGrpcAsyncIOTransport(CatalogServiceTransport):
         [CatalogService.SetDefaultBranch][google.cloud.retail.v2.CatalogService.SetDefaultBranch]
         method under a specified parent catalog.
 
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
-
         Returns:
             Callable[[~.GetDefaultBranchRequest],
                     Awaitable[~.GetDefaultBranchResponse]]:
