@@ -58,7 +58,8 @@ class CompletionServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = CompletionServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[CompletionServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -80,11 +81,9 @@ class CompletionServiceClientMeta(type):
 
 class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
     """Auto-completion service for retail.
-
     This feature is only available for users who have Retail Search
-    enabled. Please submit a form
-    `here <https://cloud.google.com/contact>`__ to contact cloud sales
-    if you are interested in using Retail Search.
+    enabled. Please enable Retail Search on Cloud Console before
+    using this feature.
     """
 
     @staticmethod
@@ -170,10 +169,16 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def catalog_path(project: str, location: str, catalog: str,) -> str:
+    def catalog_path(
+        project: str,
+        location: str,
+        catalog: str,
+    ) -> str:
         """Returns a fully-qualified catalog string."""
         return "projects/{project}/locations/{location}/catalogs/{catalog}".format(
-            project=project, location=location, catalog=catalog,
+            project=project,
+            location=location,
+            catalog=catalog,
         )
 
     @staticmethod
@@ -186,7 +191,9 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -199,9 +206,13 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -210,9 +221,13 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -221,9 +236,13 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -232,10 +251,14 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -417,12 +440,11 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> completion_service.CompleteQueryResponse:
-        r"""Completes the specified prefix with keyword suggestions.
-
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
+        r"""Completes the specified prefix with keyword
+        suggestions.
+        This feature is only available for users who have Retail
+        Search enabled. Please enable Retail Search on Cloud
+        Console before using this feature.
 
 
         .. code-block:: python
@@ -477,7 +499,12 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -491,14 +518,14 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Bulk import of processed completion dataset.
-
-        Request processing may be synchronous. Partial updating is not
-        supported.
-
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
+        Request processing is asynchronous. Partial updating is
+        not supported.
+        The operation is successfully finished only after the
+        imported suggestions are indexed successfully and ready
+        for serving. The process takes hours.
+        This feature is only available for users who have Retail
+        Search enabled. Please enable Retail Search on Cloud
+        Console before using this feature.
 
 
         .. code-block:: python
@@ -570,7 +597,12 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -599,7 +631,9 @@ class CompletionServiceClient(metaclass=CompletionServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-retail",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-retail",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
