@@ -39,6 +39,7 @@ from google.cloud.retail_v2.types import import_config
 from google.cloud.retail_v2.types import product
 from google.cloud.retail_v2.types import product as gcr_product
 from google.cloud.retail_v2.types import product_service
+from google.cloud.retail_v2.types import promotion
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -343,7 +344,12 @@ class ProductServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -444,7 +450,12 @@ class ProductServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -547,12 +558,20 @@ class ProductServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListProductsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -674,7 +693,12 @@ class ProductServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -779,7 +803,10 @@ class ProductServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def import_products(
@@ -877,7 +904,12 @@ class ProductServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -934,8 +966,8 @@ class ProductServiceAsyncClient:
         will be used.
 
         If no inventory fields are set in
-        [UpdateProductRequest.set_mask][], then any existing inventory
-        information will be preserved.
+        [SetInventoryRequest.set_mask][google.cloud.retail.v2.SetInventoryRequest.set_mask],
+        then any existing inventory information will be preserved.
 
         Pre-existing inventory information can only be updated with
         [SetInventory][google.cloud.retail.v2.ProductService.SetInventory],
@@ -944,9 +976,8 @@ class ProductServiceAsyncClient:
         [RemoveFulfillmentPlaces][google.cloud.retail.v2.ProductService.RemoveFulfillmentPlaces].
 
         This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
+        enabled. Please enable Retail Search on Cloud Console before
+        using this feature.
 
 
         .. code-block:: python
@@ -1010,6 +1041,26 @@ class ProductServiceAsyncClient:
                 provided or default value for
                 [SetInventoryRequest.set_time][google.cloud.retail.v2.SetInventoryRequest.set_time].
 
+                The caller can replace place IDs for a subset of
+                fulfillment types in the following ways:
+
+                -  Adds "fulfillment_info" in
+                   [SetInventoryRequest.set_mask][google.cloud.retail.v2.SetInventoryRequest.set_mask]
+                -  Specifies only the desired fulfillment types and
+                   corresponding place IDs to update in
+                   [SetInventoryRequest.inventory.fulfillment_info][]
+
+                The caller can clear all place IDs from a subset of
+                fulfillment types in the following ways:
+
+                -  Adds "fulfillment_info" in
+                   [SetInventoryRequest.set_mask][google.cloud.retail.v2.SetInventoryRequest.set_mask]
+                -  Specifies only the desired fulfillment types to clear
+                   in [SetInventoryRequest.inventory.fulfillment_info][]
+                -  Checks that only the desired fulfillment info types
+                   have empty
+                   [SetInventoryRequest.inventory.fulfillment_info.place_ids][]
+
                 The last update time is recorded for the following
                 inventory fields:
 
@@ -1027,9 +1078,9 @@ class ProductServiceAsyncClient:
                 should not be set.
             set_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                 Indicates which inventory fields in the provided
-                [Product][google.cloud.retail.v2.Product] to update. If
-                not set or set with empty paths, all inventory fields
-                will be updated.
+                [Product][google.cloud.retail.v2.Product] to update.
+
+                At least one field must be provided.
 
                 If an unsupported or unknown field is provided, an
                 INVALID_ARGUMENT error is returned and the entire update
@@ -1089,7 +1140,12 @@ class ProductServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1126,9 +1182,8 @@ class ProductServiceAsyncClient:
         [ListProducts][google.cloud.retail.v2.ProductService.ListProducts].
 
         This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
+        enabled. Please enable Retail Search on Cloud Console before
+        using this feature.
 
 
         .. code-block:: python
@@ -1220,7 +1275,12 @@ class ProductServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1257,9 +1317,8 @@ class ProductServiceAsyncClient:
         [ListProducts][google.cloud.retail.v2.ProductService.ListProducts].
 
         This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
+        enabled. Please enable Retail Search on Cloud Console before
+        using this feature.
 
 
         .. code-block:: python
@@ -1351,7 +1410,12 @@ class ProductServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1364,6 +1428,288 @@ class ProductServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def add_local_inventories(
+        self,
+        request: Union[product_service.AddLocalInventoriesRequest, dict] = None,
+        *,
+        product: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Updates local inventory information for a
+        [Product][google.cloud.retail.v2.Product] at a list of places,
+        while respecting the last update timestamps of each inventory
+        field.
+
+        This process is asynchronous and does not require the
+        [Product][google.cloud.retail.v2.Product] to exist before
+        updating inventory information. If the request is valid, the
+        update will be enqueued and processed downstream. As a
+        consequence, when a response is returned, updates are not
+        immediately manifested in the
+        [Product][google.cloud.retail.v2.Product] queried by
+        [GetProduct][google.cloud.retail.v2.ProductService.GetProduct]
+        or
+        [ListProducts][google.cloud.retail.v2.ProductService.ListProducts].
+
+        Local inventory information can only be modified using this
+        method.
+        [CreateProduct][google.cloud.retail.v2.ProductService.CreateProduct]
+        and
+        [UpdateProduct][google.cloud.retail.v2.ProductService.UpdateProduct]
+        has no effect on local inventories.
+
+        This feature is only available for users who have Retail Search
+        enabled. Please enable Retail Search on Cloud Console before
+        using this feature.
+
+
+        .. code-block:: python
+
+            from google.cloud import retail_v2
+
+            def sample_add_local_inventories():
+                # Create a client
+                client = retail_v2.ProductServiceClient()
+
+                # Initialize request argument(s)
+                request = retail_v2.AddLocalInventoriesRequest(
+                    product="product_value",
+                )
+
+                # Make the request
+                operation = client.add_local_inventories(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.retail_v2.types.AddLocalInventoriesRequest, dict]):
+                The request object. Request message for
+                [AddLocalInventories][] method.
+            product (:class:`str`):
+                Required. Full resource name of
+                [Product][google.cloud.retail.v2.Product], such as
+                ``projects/*/locations/global/catalogs/default_catalog/branches/default_branch/products/some_product_id``.
+
+                If the caller does not have permission to access the
+                [Product][google.cloud.retail.v2.Product], regardless of
+                whether or not it exists, a PERMISSION_DENIED error is
+                returned.
+
+                This corresponds to the ``product`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be :class:`google.cloud.retail_v2.types.AddLocalInventoriesResponse` Response of the [AddLocalInventories][] API. Currently empty because
+                   there is no meaningful response populated from the
+                   [AddLocalInventories][] method.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([product])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = product_service.AddLocalInventoriesRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if product is not None:
+            request.product = product
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.add_local_inventories,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("product", request.product),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            product_service.AddLocalInventoriesResponse,
+            metadata_type=product_service.AddLocalInventoriesMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def remove_local_inventories(
+        self,
+        request: Union[product_service.RemoveLocalInventoriesRequest, dict] = None,
+        *,
+        product: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Remove local inventory information for a
+        [Product][google.cloud.retail.v2.Product] at a list of places at
+        a removal timestamp.
+
+        This process is asynchronous. If the request is valid, the
+        removal will be enqueued and processed downstream. As a
+        consequence, when a response is returned, removals are not
+        immediately manifested in the
+        [Product][google.cloud.retail.v2.Product] queried by
+        [GetProduct][google.cloud.retail.v2.ProductService.GetProduct]
+        or
+        [ListProducts][google.cloud.retail.v2.ProductService.ListProducts].
+
+        Local inventory information can only be removed using this
+        method.
+        [CreateProduct][google.cloud.retail.v2.ProductService.CreateProduct]
+        and
+        [UpdateProduct][google.cloud.retail.v2.ProductService.UpdateProduct]
+        has no effect on local inventories.
+
+        This feature is only available for users who have Retail Search
+        enabled. Please enable Retail Search on Cloud Console before
+        using this feature.
+
+
+        .. code-block:: python
+
+            from google.cloud import retail_v2
+
+            def sample_remove_local_inventories():
+                # Create a client
+                client = retail_v2.ProductServiceClient()
+
+                # Initialize request argument(s)
+                request = retail_v2.RemoveLocalInventoriesRequest(
+                    product="product_value",
+                    place_ids=['place_ids_value_1', 'place_ids_value_2'],
+                )
+
+                # Make the request
+                operation = client.remove_local_inventories(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.retail_v2.types.RemoveLocalInventoriesRequest, dict]):
+                The request object. Request message for
+                [RemoveLocalInventories][] method.
+            product (:class:`str`):
+                Required. Full resource name of
+                [Product][google.cloud.retail.v2.Product], such as
+                ``projects/*/locations/global/catalogs/default_catalog/branches/default_branch/products/some_product_id``.
+
+                If the caller does not have permission to access the
+                [Product][google.cloud.retail.v2.Product], regardless of
+                whether or not it exists, a PERMISSION_DENIED error is
+                returned.
+
+                This corresponds to the ``product`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be :class:`google.cloud.retail_v2.types.RemoveLocalInventoriesResponse` Response of the [RemoveLocalInventories][] API. Currently empty because
+                   there is no meaningful response populated from the
+                   [RemoveLocalInventories][] method.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([product])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = product_service.RemoveLocalInventoriesRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if product is not None:
+            request.product = product
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.remove_local_inventories,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("product", request.product),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            product_service.RemoveLocalInventoriesResponse,
+            metadata_type=product_service.RemoveLocalInventoriesMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def __aenter__(self):
         return self
 
@@ -1373,7 +1719,9 @@ class ProductServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-retail",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-retail",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
