@@ -53,7 +53,10 @@ class SearchServiceClientMeta(type):
     _transport_registry["grpc"] = SearchServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = SearchServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[SearchServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[SearchServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -74,11 +77,9 @@ class SearchServiceClientMeta(type):
 
 class SearchServiceClient(metaclass=SearchServiceClientMeta):
     """Service for search.
-
     This feature is only available for users who have Retail Search
-    enabled. Please submit a form
-    `here <https://cloud.google.com/contact>`__ to contact cloud sales
-    if you are interested in using Retail Search.
+    enabled. Please enable Retail Search on Cloud Console before
+    using this feature.
     """
 
     @staticmethod
@@ -164,10 +165,18 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def branch_path(project: str, location: str, catalog: str, branch: str,) -> str:
+    def branch_path(
+        project: str,
+        location: str,
+        catalog: str,
+        branch: str,
+    ) -> str:
         """Returns a fully-qualified branch string."""
         return "projects/{project}/locations/{location}/catalogs/{catalog}/branches/{branch}".format(
-            project=project, location=location, catalog=catalog, branch=branch,
+            project=project,
+            location=location,
+            catalog=catalog,
+            branch=branch,
         )
 
     @staticmethod
@@ -181,7 +190,11 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
 
     @staticmethod
     def product_path(
-        project: str, location: str, catalog: str, branch: str, product: str,
+        project: str,
+        location: str,
+        catalog: str,
+        branch: str,
+        product: str,
     ) -> str:
         """Returns a fully-qualified product string."""
         return "projects/{project}/locations/{location}/catalogs/{catalog}/branches/{branch}/products/{product}".format(
@@ -202,7 +215,9 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -215,9 +230,13 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -226,9 +245,13 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -237,9 +260,13 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -248,10 +275,14 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -434,11 +465,9 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.SearchPager:
         r"""Performs a search.
-
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
+        This feature is only available for users who have Retail
+        Search enabled. Please enable Retail Search on Cloud
+        Console before using this feature.
 
 
         .. code-block:: python
@@ -504,12 +533,20 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.SearchPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -531,7 +568,9 @@ class SearchServiceClient(metaclass=SearchServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-retail",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-retail",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
