@@ -32,11 +32,9 @@ class SearchServiceGrpcTransport(SearchServiceTransport):
     """gRPC backend transport for SearchService.
 
     Service for search.
-
     This feature is only available for users who have Retail Search
-    enabled. Please submit a form
-    `here <https://cloud.google.com/contact>`__ to contact cloud sales
-    if you are interested in using Retail Search.
+    enabled. Please enable Retail Search on Cloud Console before
+    using this feature.
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -229,8 +227,7 @@ class SearchServiceGrpcTransport(SearchServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -240,11 +237,9 @@ class SearchServiceGrpcTransport(SearchServiceTransport):
         r"""Return a callable for the search method over gRPC.
 
         Performs a search.
-
-        This feature is only available for users who have Retail Search
-        enabled. Please submit a form
-        `here <https://cloud.google.com/contact>`__ to contact cloud
-        sales if you are interested in using Retail Search.
+        This feature is only available for users who have Retail
+        Search enabled. Please enable Retail Search on Cloud
+        Console before using this feature.
 
         Returns:
             Callable[[~.SearchRequest],
