@@ -232,8 +232,7 @@ class UserEventServiceGrpcTransport(UserEventServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -377,16 +376,17 @@ class UserEventServiceGrpcTransport(UserEventServiceTransport):
     ]:
         r"""Return a callable for the rejoin user events method over gRPC.
 
-        Triggers a user event rejoin operation with latest
+        Starts a user event rejoin operation with latest
         product catalog. Events will not be annotated with
         detailed product information if product is missing from
         the catalog at the time the user event is ingested, and
         these events are stored as unjoined events with a
-        limited usage on training and serving. This API can be
-        used to trigger a 'join' operation on specified events
+        limited usage on training and serving. This method can
+        be used to start a join operation on specified events
         with latest version of product catalog. It can also be
-        used to correct events joined with wrong product
-        catalog.
+        used to correct events joined with the wrong product
+        catalog. A rejoin operation can take hours or days to
+        complete.
 
         Returns:
             Callable[[~.RejoinUserEventsRequest],
