@@ -30,7 +30,7 @@ __protobuf__ = proto.module(
         "PriceInfo",
         "Rating",
         "UserInfo",
-        "Promotion",
+        "LocalInventory",
     },
 )
 
@@ -70,8 +70,14 @@ class Audience(proto.Message):
             `Product.audience.suggestedMaxAge <https://schema.org/suggestedMaxAge>`__.
     """
 
-    genders = proto.RepeatedField(proto.STRING, number=1,)
-    age_groups = proto.RepeatedField(proto.STRING, number=2,)
+    genders = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    age_groups = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ColorInfo(proto.Message):
@@ -112,8 +118,14 @@ class ColorInfo(proto.Message):
             `Product.color <https://schema.org/color>`__.
     """
 
-    color_families = proto.RepeatedField(proto.STRING, number=1,)
-    colors = proto.RepeatedField(proto.STRING, number=2,)
+    color_families = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    colors = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
 
 
 class CustomAttribute(proto.Message):
@@ -125,10 +137,8 @@ class CustomAttribute(proto.Message):
             The textual values of this custom attribute. For example,
             ``["yellow", "green"]`` when the key is "color".
 
-            At most 400 values are allowed. Empty values are not
-            allowed. Each value must be a UTF-8 encoded string with a
-            length limit of 256 characters. Otherwise, an
-            INVALID_ARGUMENT error is returned.
+            Empty string is not allowed. Otherwise, an INVALID_ARGUMENT
+            error is returned.
 
             Exactly one of
             [text][google.cloud.retail.v2.CustomAttribute.text] or
@@ -139,17 +149,17 @@ class CustomAttribute(proto.Message):
             The numerical values of this custom attribute. For example,
             ``[2.3, 15.4]`` when the key is "lengths_cm".
 
-            At most 400 values are allowed.Otherwise, an
-            INVALID_ARGUMENT error is returned.
-
             Exactly one of
             [text][google.cloud.retail.v2.CustomAttribute.text] or
             [numbers][google.cloud.retail.v2.CustomAttribute.numbers]
             should be set. Otherwise, an INVALID_ARGUMENT error is
             returned.
         searchable (bool):
-            If true, custom attribute values are searchable by text
-            queries in
+            This field will only be used when
+            [AttributesConfig.attribute_config_level][] of the
+            [Catalog][google.cloud.retail.v2.Catalog] is
+            'PRODUCT_LEVEL_ATTRIBUTE_CONFIG', if true, custom attribute
+            values are searchable by text queries in
             [SearchService.Search][google.cloud.retail.v2.SearchService.Search].
 
             This field is ignored in a
@@ -161,8 +171,12 @@ class CustomAttribute(proto.Message):
 
             This field is a member of `oneof`_ ``_searchable``.
         indexable (bool):
-            If true, custom attribute values are indexed, so that it can
-            be filtered, faceted or boosted in
+            This field will only be used when
+            [AttributesConfig.attribute_config_level][] of the
+            [Catalog][google.cloud.retail.v2.Catalog] is
+            'PRODUCT_LEVEL_ATTRIBUTE_CONFIG', if true, custom attribute
+            values are indexed, so that it can be filtered, faceted or
+            boosted in
             [SearchService.Search][google.cloud.retail.v2.SearchService.Search].
 
             This field is ignored in a
@@ -178,10 +192,24 @@ class CustomAttribute(proto.Message):
             This field is a member of `oneof`_ ``_indexable``.
     """
 
-    text = proto.RepeatedField(proto.STRING, number=1,)
-    numbers = proto.RepeatedField(proto.DOUBLE, number=2,)
-    searchable = proto.Field(proto.BOOL, number=3, optional=True,)
-    indexable = proto.Field(proto.BOOL, number=4, optional=True,)
+    text = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    numbers = proto.RepeatedField(
+        proto.DOUBLE,
+        number=2,
+    )
+    searchable = proto.Field(
+        proto.BOOL,
+        number=3,
+        optional=True,
+    )
+    indexable = proto.Field(
+        proto.BOOL,
+        number=4,
+        optional=True,
+    )
 
 
 class FulfillmentInfo(proto.Message):
@@ -223,12 +251,22 @@ class FulfillmentInfo(proto.Message):
             Otherwise, an INVALID_ARGUMENT error is returned.
     """
 
-    type_ = proto.Field(proto.STRING, number=1,)
-    place_ids = proto.RepeatedField(proto.STRING, number=2,)
+    type_ = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    place_ids = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
 
 
 class Image(proto.Message):
-    r"""[Product][google.cloud.retail.v2.Product] thumbnail/detail image.
+    r"""[Product][google.cloud.retail.v2.Product] image. Recommendations AI
+    and Retail Search do not use product images to improve prediction
+    and search results. However, product images can be returned in
+    results, and are shown in prediction or search previews in the
+    console.
 
     Attributes:
         uri (str):
@@ -254,9 +292,18 @@ class Image(proto.Message):
             INVALID_ARGUMENT error is returned.
     """
 
-    uri = proto.Field(proto.STRING, number=1,)
-    height = proto.Field(proto.INT32, number=2,)
-    width = proto.Field(proto.INT32, number=3,)
+    uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    height = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    width = proto.Field(
+        proto.INT32,
+        number=3,
+    )
 
 
 class Interval(proto.Message):
@@ -288,10 +335,26 @@ class Interval(proto.Message):
             This field is a member of `oneof`_ ``max``.
     """
 
-    minimum = proto.Field(proto.DOUBLE, number=1, oneof="min",)
-    exclusive_minimum = proto.Field(proto.DOUBLE, number=2, oneof="min",)
-    maximum = proto.Field(proto.DOUBLE, number=3, oneof="max",)
-    exclusive_maximum = proto.Field(proto.DOUBLE, number=4, oneof="max",)
+    minimum = proto.Field(
+        proto.DOUBLE,
+        number=1,
+        oneof="min",
+    )
+    exclusive_minimum = proto.Field(
+        proto.DOUBLE,
+        number=2,
+        oneof="min",
+    )
+    maximum = proto.Field(
+        proto.DOUBLE,
+        number=3,
+        oneof="max",
+    )
+    exclusive_maximum = proto.Field(
+        proto.DOUBLE,
+        number=4,
+        oneof="max",
+    )
 
 
 class PriceInfo(proto.Message):
@@ -319,7 +382,7 @@ class PriceInfo(proto.Message):
             Google Merchant Center property
             `price <https://support.google.com/merchants/answer/6324371>`__.
             Schema.org property
-            `Offer.priceSpecification <https://schema.org/priceSpecification>`__.
+            `Offer.price <https://schema.org/price>`__.
         original_price (float):
             Price of the product without any discount. If zero, by
             default set to be the
@@ -408,20 +471,48 @@ class PriceInfo(proto.Message):
                 [Product.primary_product_id][google.cloud.retail.v2.Product.primary_product_id].
         """
 
-        price = proto.Field(proto.MESSAGE, number=1, message="Interval",)
-        original_price = proto.Field(proto.MESSAGE, number=2, message="Interval",)
+        price = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message="Interval",
+        )
+        original_price = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message="Interval",
+        )
 
-    currency_code = proto.Field(proto.STRING, number=1,)
-    price = proto.Field(proto.FLOAT, number=2,)
-    original_price = proto.Field(proto.FLOAT, number=3,)
-    cost = proto.Field(proto.FLOAT, number=4,)
+    currency_code = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    price = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
+    original_price = proto.Field(
+        proto.FLOAT,
+        number=3,
+    )
+    cost = proto.Field(
+        proto.FLOAT,
+        number=4,
+    )
     price_effective_time = proto.Field(
-        proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
     )
     price_expire_time = proto.Field(
-        proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
+    price_range = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=PriceRange,
     )
-    price_range = proto.Field(proto.MESSAGE, number=7, message=PriceRange,)
 
 
 class Rating(proto.Message):
@@ -452,9 +543,18 @@ class Rating(proto.Message):
             with 1 star, 14 ratings with 2 star, and so on.
     """
 
-    rating_count = proto.Field(proto.INT32, number=1,)
-    average_rating = proto.Field(proto.FLOAT, number=2,)
-    rating_histogram = proto.RepeatedField(proto.INT32, number=3,)
+    rating_count = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    average_rating = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
+    rating_histogram = proto.RepeatedField(
+        proto.INT32,
+        number=3,
+    )
 
 
 class UserInfo(proto.Message):
@@ -465,25 +565,29 @@ class UserInfo(proto.Message):
             Highly recommended for logged-in users. Unique identifier
             for logged-in user, such as a user name.
 
+            Always use a hashed value for this ID.
+
             The field must be a UTF-8 encoded string with a length limit
             of 128 characters. Otherwise, an INVALID_ARGUMENT error is
             returned.
         ip_address (str):
-            The end user's IP address. Required for getting
-            [SearchResponse.sponsored_results][google.cloud.retail.v2.SearchResponse.sponsored_results].
-            This field is used to extract location information for
-            personalization.
+            The end user's IP address. This field is used to extract
+            location information for personalization.
 
             This field must be either an IPv4 address (e.g.
             "104.133.9.80") or an IPv6 address (e.g.
             "2001:0db8:85a3:0000:0000:8a2e:0370:7334"). Otherwise, an
             INVALID_ARGUMENT error is returned.
 
-            This should not be set when using the JavaScript tag in
-            [UserEventService.CollectUserEvent][google.cloud.retail.v2.UserEventService.CollectUserEvent]
-            or if
-            [direct_user_request][google.cloud.retail.v2.UserInfo.direct_user_request]
-            is set.
+            This should not be set when:
+
+            -  setting
+               [SearchRequest.user_info][google.cloud.retail.v2.SearchRequest.user_info].
+            -  using the JavaScript tag in
+               [UserEventService.CollectUserEvent][google.cloud.retail.v2.UserEventService.CollectUserEvent]
+               or if
+               [direct_user_request][google.cloud.retail.v2.UserInfo.direct_user_request]
+               is set.
         user_agent (str):
             User agent as included in the HTTP header. Required for
             getting
@@ -513,30 +617,104 @@ class UserInfo(proto.Message):
             [UserEventService.CollectUserEvent][google.cloud.retail.v2.UserEventService.CollectUserEvent].
     """
 
-    user_id = proto.Field(proto.STRING, number=1,)
-    ip_address = proto.Field(proto.STRING, number=2,)
-    user_agent = proto.Field(proto.STRING, number=3,)
-    direct_user_request = proto.Field(proto.BOOL, number=4,)
+    user_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    ip_address = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    user_agent = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    direct_user_request = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
 
 
-class Promotion(proto.Message):
-    r"""Promotion information.
+class LocalInventory(proto.Message):
+    r"""The inventory information at a place (e.g. a store)
+    identified by a place ID.
 
     Attributes:
-        promotion_id (str):
-            ID of the promotion. For example, "free gift".
-
-            The value value must be a UTF-8 encoded string with a length
-            limit of 128 characters, and match the pattern:
-            ``[a-zA-Z][a-zA-Z0-9_]*``. For example, id0LikeThis or
-            ID_1_LIKE_THIS. Otherwise, an INVALID_ARGUMENT error is
-            returned.
+        place_id (str):
+            The place ID for the current set of inventory
+            information.
+        price_info (google.cloud.retail_v2.types.PriceInfo):
+            Product price and cost information.
 
             Google Merchant Center property
-            `promotion <https://support.google.com/merchants/answer/7050148>`__.
+            `price <https://support.google.com/merchants/answer/6324371>`__.
+        attributes (Sequence[google.cloud.retail_v2.types.LocalInventory.AttributesEntry]):
+            Additional local inventory attributes, for example, store
+            name, promotion tags, etc.
+
+            This field needs to pass all below criteria, otherwise an
+            INVALID_ARGUMENT error is returned:
+
+            -  At most 30 attributes are allowed.
+            -  The key must be a UTF-8 encoded string with a length
+               limit of 32 characters.
+            -  The key must match the pattern:
+               ``[a-zA-Z0-9][a-zA-Z0-9_]*``. For example, key0LikeThis
+               or KEY_1_LIKE_THIS.
+            -  The attribute values must be of the same type (text or
+               number).
+            -  Only 1 value is allowed for each attribute.
+            -  For text values, the length limit is 256 UTF-8
+               characters.
+            -  The attribute does not support search. The ``searchable``
+               field should be unset or set to false.
+            -  The max summed total bytes of custom attribute keys and
+               values per product is 5MiB.
+        fulfillment_types (Sequence[str]):
+            Input only. Supported fulfillment types. Valid fulfillment
+            type values include commonly used types (such as pickup in
+            store and same day delivery), and custom types. Customers
+            have to map custom types to their display names before
+            rendering UI.
+
+            Supported values:
+
+            -  "pickup-in-store"
+            -  "ship-to-store"
+            -  "same-day-delivery"
+            -  "next-day-delivery"
+            -  "custom-type-1"
+            -  "custom-type-2"
+            -  "custom-type-3"
+            -  "custom-type-4"
+            -  "custom-type-5"
+
+            If this field is set to an invalid value other than these,
+            an INVALID_ARGUMENT error is returned.
+
+            All the elements must be distinct. Otherwise, an
+            INVALID_ARGUMENT error is returned.
     """
 
-    promotion_id = proto.Field(proto.STRING, number=1,)
+    place_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    price_info = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="PriceInfo",
+    )
+    attributes = proto.MapField(
+        proto.STRING,
+        proto.MESSAGE,
+        number=3,
+        message="CustomAttribute",
+    )
+    fulfillment_types = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
