@@ -20,7 +20,10 @@ from google.cloud.retail_v2.types import common
 
 __protobuf__ = proto.module(
     package="google.cloud.retail.v2",
-    manifest={"CompleteQueryRequest", "CompleteQueryResponse",},
+    manifest={
+        "CompleteQueryRequest",
+        "CompleteQueryResponse",
+    },
 )
 
 
@@ -38,23 +41,24 @@ class CompleteQueryRequest(proto.Message):
             suggestions.
             The maximum number of allowed characters is 255.
         visitor_id (str):
-            A unique identifier for tracking visitors. For example, this
-            could be implemented with an HTTP cookie, which should be
-            able to uniquely identify a visitor on a single device. This
-            unique identifier should not change if the visitor logs in
-            or out of the website.
+            Required field. A unique identifier for tracking visitors.
+            For example, this could be implemented with an HTTP cookie,
+            which should be able to uniquely identify a visitor on a
+            single device. This unique identifier should not change if
+            the visitor logs in or out of the website.
 
             The field must be a UTF-8 encoded string with a length limit
             of 128 characters. Otherwise, an INVALID_ARGUMENT error is
             returned.
         language_codes (Sequence[str]):
-            The list of languages of the query. This is the BCP-47
-            language code, such as "en-US" or "sr-Latn". For more
-            information, see `Tags for Identifying
-            Languages <https://tools.ietf.org/html/bcp47>`__.
-
-            The maximum number of allowed characters is 255. Only
-            "en-US" is currently supported.
+            The language filters applied to the output suggestions. If
+            set, it should contain the language of the query. If not
+            set, suggestions are returned without considering language
+            restrictions. This is the BCP-47 language code, such as
+            "en-US" or "sr-Latn". For more information, see `Tags for
+            Identifying
+            Languages <https://tools.ietf.org/html/bcp47>`__. The
+            maximum number of language codes is 3.
         device_type (str):
             The device type context for completion suggestions. It is
             useful to apply different suggestions on different device
@@ -95,13 +99,34 @@ class CompleteQueryRequest(proto.Message):
             higher, it will be capped by 20.
     """
 
-    catalog = proto.Field(proto.STRING, number=1,)
-    query = proto.Field(proto.STRING, number=2,)
-    visitor_id = proto.Field(proto.STRING, number=7,)
-    language_codes = proto.RepeatedField(proto.STRING, number=3,)
-    device_type = proto.Field(proto.STRING, number=4,)
-    dataset = proto.Field(proto.STRING, number=6,)
-    max_suggestions = proto.Field(proto.INT32, number=5,)
+    catalog = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    query = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    visitor_id = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    language_codes = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    device_type = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    dataset = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    max_suggestions = proto.Field(
+        proto.INT32,
+        number=5,
+    )
 
 
 class CompleteQueryResponse(proto.Message):
@@ -114,9 +139,9 @@ class CompleteQueryResponse(proto.Message):
             top suggestion.
         attribution_token (str):
             A unique complete token. This should be included in the
-            [SearchRequest][google.cloud.retail.v2.SearchRequest]
-            resulting from this completion, which enables accurate
-            attribution of complete model performance.
+            [UserEvent.completion_detail][google.cloud.retail.v2.UserEvent.completion_detail]
+            for search events resulting from this completion, which
+            enables accurate attribution of complete model performance.
         recent_search_results (Sequence[google.cloud.retail_v2.types.CompleteQueryResponse.RecentSearchResult]):
             Matched recent searches of this user. The maximum number of
             recent searches is 10. This field is a restricted feature.
@@ -147,13 +172,23 @@ class CompleteQueryResponse(proto.Message):
             suggestion (str):
                 The suggestion for the query.
             attributes (Sequence[google.cloud.retail_v2.types.CompleteQueryResponse.CompletionResult.AttributesEntry]):
-                Additional custom attributes ingested through
-                BigQuery.
+                Custom attributes for the suggestion term.
+
+                -  For "user-data", the attributes are additional custom
+                   attributes ingested through BigQuery.
+                -  For "cloud-retail", the attributes are product attributes
+                   generated by Cloud Retail.
         """
 
-        suggestion = proto.Field(proto.STRING, number=1,)
+        suggestion = proto.Field(
+            proto.STRING,
+            number=1,
+        )
         attributes = proto.MapField(
-            proto.STRING, proto.MESSAGE, number=2, message=common.CustomAttribute,
+            proto.STRING,
+            proto.MESSAGE,
+            number=2,
+            message=common.CustomAttribute,
         )
 
     class RecentSearchResult(proto.Message):
@@ -164,14 +199,24 @@ class CompleteQueryResponse(proto.Message):
                 The recent search query.
         """
 
-        recent_search = proto.Field(proto.STRING, number=1,)
+        recent_search = proto.Field(
+            proto.STRING,
+            number=1,
+        )
 
     completion_results = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=CompletionResult,
+        proto.MESSAGE,
+        number=1,
+        message=CompletionResult,
+    )
+    attribution_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    attribution_token = proto.Field(proto.STRING, number=2,)
     recent_search_results = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=RecentSearchResult,
+        proto.MESSAGE,
+        number=3,
+        message=RecentSearchResult,
     )
 
 
