@@ -80,10 +80,25 @@ class GcsSource(proto.Message):
                [UserEvent][google.cloud.retail.v2.UserEvent] per line.
             -  ``user_event_ga360``: Using
                https://support.google.com/analytics/answer/3437719.
+
+            Supported values for control imports:
+
+            -  'control' (default): One JSON [Control][] per line.
+
+            Supported values for catalog attribute imports:
+
+            -  'catalog_attribute' (default): One CSV
+               [CatalogAttribute][] per line.
     """
 
-    input_uris = proto.RepeatedField(proto.STRING, number=1,)
-    data_schema = proto.Field(proto.STRING, number=2,)
+    input_uris = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    data_schema = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class BigQuerySource(proto.Message):
@@ -136,18 +151,47 @@ class BigQuerySource(proto.Message):
 
             -  ``user_event`` (default): One JSON
                [UserEvent][google.cloud.retail.v2.UserEvent] per line.
-            -  ``user_event_ga360``: Using
+            -  ``user_event_ga360``: The schema is available here:
                https://support.google.com/analytics/answer/3437719.
+            -  ``user_event_ga4``: This feature is in private preview.
+               Please contact the support team for importing Google
+               Analytics 4 events. The schema is available here:
+               https://support.google.com/analytics/answer/7029846.
+
+            Supported values for auto-completion imports:
+
+            -  ``suggestions`` (default): One JSON completion suggestion
+               per line.
+            -  ``denylist``: One JSON deny suggestion per line.
+            -  ``allowlist``: One JSON allow suggestion per line.
     """
 
     partition_date = proto.Field(
-        proto.MESSAGE, number=6, oneof="partition", message=date_pb2.Date,
+        proto.MESSAGE,
+        number=6,
+        oneof="partition",
+        message=date_pb2.Date,
+    )
+    project_id = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    dataset_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    table_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    gcs_staging_dir = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    data_schema = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    project_id = proto.Field(proto.STRING, number=5,)
-    dataset_id = proto.Field(proto.STRING, number=1,)
-    table_id = proto.Field(proto.STRING, number=2,)
-    gcs_staging_dir = proto.Field(proto.STRING, number=3,)
-    data_schema = proto.Field(proto.STRING, number=4,)
 
 
 class ProductInlineSource(proto.Message):
@@ -162,7 +206,11 @@ class ProductInlineSource(proto.Message):
             max of 100 items.
     """
 
-    products = proto.RepeatedField(proto.MESSAGE, number=1, message=product.Product,)
+    products = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=product.Product,
+    )
 
 
 class UserEventInlineSource(proto.Message):
@@ -176,7 +224,9 @@ class UserEventInlineSource(proto.Message):
     """
 
     user_events = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=user_event.UserEvent,
+        proto.MESSAGE,
+        number=1,
+        message=user_event.UserEvent,
     )
 
 
@@ -187,15 +237,19 @@ class ImportErrorsConfig(proto.Message):
 
     Attributes:
         gcs_prefix (str):
-            Google Cloud Storage path for import errors. This must be an
-            empty, existing Cloud Storage bucket. Import errors will be
-            written to a file in this bucket, one per line, as a
-            JSON-encoded ``google.rpc.Status`` message.
+            Google Cloud Storage prefix for import errors. This must be
+            an empty, existing Cloud Storage directory. Import errors
+            will be written to sharded files in this directory, one per
+            line, as a JSON-encoded ``google.rpc.Status`` message.
 
             This field is a member of `oneof`_ ``destination``.
     """
 
-    gcs_prefix = proto.Field(proto.STRING, number=1, oneof="destination",)
+    gcs_prefix = proto.Field(
+        proto.STRING,
+        number=1,
+        oneof="destination",
+    )
 
 
 class ImportProductsRequest(proto.Message):
@@ -210,16 +264,7 @@ class ImportProductsRequest(proto.Message):
             permission. If updateMask is specified, requires
             products.update permission.
         request_id (str):
-            Unique identifier provided by client, within the ancestor
-            dataset scope. Ensures idempotency and used for request
-            deduplication. Server-generated if unspecified. Up to 128
-            characters long and must match the pattern:
-            ``[a-zA-Z0-9_]+``. This is returned as [Operation.name][] in
-            [ImportMetadata][google.cloud.retail.v2.ImportMetadata].
-
-            Only supported when
-            [ImportProductsRequest.reconciliation_mode][google.cloud.retail.v2.ImportProductsRequest.reconciliation_mode]
-            is set to ``FULL``.
+            Deprecated. This field has no effect.
         input_config (google.cloud.retail_v2.types.ProductInputConfig):
             Required. The desired input location of the
             data.
@@ -255,15 +300,38 @@ class ImportProductsRequest(proto.Message):
         INCREMENTAL = 1
         FULL = 2
 
-    parent = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=6,)
-    input_config = proto.Field(proto.MESSAGE, number=2, message="ProductInputConfig",)
-    errors_config = proto.Field(proto.MESSAGE, number=3, message="ImportErrorsConfig",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    input_config = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="ProductInputConfig",
+    )
+    errors_config = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="ImportErrorsConfig",
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=4, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=4,
+        message=field_mask_pb2.FieldMask,
+    )
+    reconciliation_mode = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=ReconciliationMode,
+    )
+    notification_pubsub_topic = proto.Field(
+        proto.STRING,
+        number=7,
     )
-    reconciliation_mode = proto.Field(proto.ENUM, number=5, enum=ReconciliationMode,)
-    notification_pubsub_topic = proto.Field(proto.STRING, number=7,)
 
 
 class ImportUserEventsRequest(proto.Message):
@@ -282,9 +350,20 @@ class ImportUserEventsRequest(proto.Message):
             event imports.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    input_config = proto.Field(proto.MESSAGE, number=2, message="UserEventInputConfig",)
-    errors_config = proto.Field(proto.MESSAGE, number=3, message="ImportErrorsConfig",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    input_config = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="UserEventInputConfig",
+    )
+    errors_config = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="ImportErrorsConfig",
+    )
 
 
 class ImportCompletionDataRequest(proto.Message):
@@ -309,11 +388,19 @@ class ImportCompletionDataRequest(proto.Message):
             ``projects/{project}/topics/{topic}``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     input_config = proto.Field(
-        proto.MESSAGE, number=2, message="CompletionDataInputConfig",
+        proto.MESSAGE,
+        number=2,
+        message="CompletionDataInputConfig",
+    )
+    notification_pubsub_topic = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    notification_pubsub_topic = proto.Field(proto.STRING, number=3,)
 
 
 class ProductInputConfig(proto.Message):
@@ -344,13 +431,22 @@ class ProductInputConfig(proto.Message):
     """
 
     product_inline_source = proto.Field(
-        proto.MESSAGE, number=1, oneof="source", message="ProductInlineSource",
+        proto.MESSAGE,
+        number=1,
+        oneof="source",
+        message="ProductInlineSource",
     )
     gcs_source = proto.Field(
-        proto.MESSAGE, number=2, oneof="source", message="GcsSource",
+        proto.MESSAGE,
+        number=2,
+        oneof="source",
+        message="GcsSource",
     )
     big_query_source = proto.Field(
-        proto.MESSAGE, number=3, oneof="source", message="BigQuerySource",
+        proto.MESSAGE,
+        number=3,
+        oneof="source",
+        message="BigQuerySource",
     )
 
 
@@ -382,13 +478,22 @@ class UserEventInputConfig(proto.Message):
     """
 
     user_event_inline_source = proto.Field(
-        proto.MESSAGE, number=1, oneof="source", message="UserEventInlineSource",
+        proto.MESSAGE,
+        number=1,
+        oneof="source",
+        message="UserEventInlineSource",
     )
     gcs_source = proto.Field(
-        proto.MESSAGE, number=2, oneof="source", message="GcsSource",
+        proto.MESSAGE,
+        number=2,
+        oneof="source",
+        message="GcsSource",
     )
     big_query_source = proto.Field(
-        proto.MESSAGE, number=3, oneof="source", message="BigQuerySource",
+        proto.MESSAGE,
+        number=3,
+        oneof="source",
+        message="BigQuerySource",
     )
 
 
@@ -410,7 +515,10 @@ class CompletionDataInputConfig(proto.Message):
     """
 
     big_query_source = proto.Field(
-        proto.MESSAGE, number=1, oneof="source", message="BigQuerySource",
+        proto.MESSAGE,
+        number=1,
+        oneof="source",
+        message="BigQuerySource",
     )
 
 
@@ -432,9 +540,7 @@ class ImportMetadata(proto.Message):
             Count of entries that encountered errors
             while processing.
         request_id (str):
-            Id of the request / operation. This is
-            parroting back the requestId that was passed in
-            the request.
+            Deprecated. This field is never set.
         notification_pubsub_topic (str):
             Pub/Sub topic for receiving notification. If this field is
             set, when the import is finished, a notification will be
@@ -444,12 +550,32 @@ class ImportMetadata(proto.Message):
             ``projects/{project}/topics/{topic}``.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    success_count = proto.Field(proto.INT64, number=3,)
-    failure_count = proto.Field(proto.INT64, number=4,)
-    request_id = proto.Field(proto.STRING, number=5,)
-    notification_pubsub_topic = proto.Field(proto.STRING, number=6,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    success_count = proto.Field(
+        proto.INT64,
+        number=3,
+    )
+    failure_count = proto.Field(
+        proto.INT64,
+        number=4,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    notification_pubsub_topic = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ImportProductsResponse(proto.Message):
@@ -469,9 +595,15 @@ class ImportProductsResponse(proto.Message):
     """
 
     error_samples = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=status_pb2.Status,
+        proto.MESSAGE,
+        number=1,
+        message=status_pb2.Status,
+    )
+    errors_config = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="ImportErrorsConfig",
     )
-    errors_config = proto.Field(proto.MESSAGE, number=2, message="ImportErrorsConfig",)
 
 
 class ImportUserEventsResponse(proto.Message):
@@ -493,11 +625,19 @@ class ImportUserEventsResponse(proto.Message):
     """
 
     error_samples = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=status_pb2.Status,
+        proto.MESSAGE,
+        number=1,
+        message=status_pb2.Status,
+    )
+    errors_config = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="ImportErrorsConfig",
     )
-    errors_config = proto.Field(proto.MESSAGE, number=2, message="ImportErrorsConfig",)
     import_summary = proto.Field(
-        proto.MESSAGE, number=3, message="UserEventImportSummary",
+        proto.MESSAGE,
+        number=3,
+        message="UserEventImportSummary",
     )
 
 
@@ -515,8 +655,14 @@ class UserEventImportSummary(proto.Message):
             catalog.
     """
 
-    joined_events_count = proto.Field(proto.INT64, number=1,)
-    unjoined_events_count = proto.Field(proto.INT64, number=2,)
+    joined_events_count = proto.Field(
+        proto.INT64,
+        number=1,
+    )
+    unjoined_events_count = proto.Field(
+        proto.INT64,
+        number=2,
+    )
 
 
 class ImportCompletionDataResponse(proto.Message):
@@ -533,7 +679,9 @@ class ImportCompletionDataResponse(proto.Message):
     """
 
     error_samples = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=status_pb2.Status,
+        proto.MESSAGE,
+        number=1,
+        message=status_pb2.Status,
     )
 
 
