@@ -15,6 +15,7 @@
 #
 import proto  # type: ignore
 
+from google.cloud.retail_v2.types import common
 from google.cloud.retail_v2.types import product as gcr_product
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -35,6 +36,12 @@ __protobuf__ = proto.module(
         "AddFulfillmentPlacesRequest",
         "AddFulfillmentPlacesMetadata",
         "AddFulfillmentPlacesResponse",
+        "AddLocalInventoriesRequest",
+        "AddLocalInventoriesMetadata",
+        "AddLocalInventoriesResponse",
+        "RemoveLocalInventoriesRequest",
+        "RemoveLocalInventoriesMetadata",
+        "RemoveLocalInventoriesResponse",
         "RemoveFulfillmentPlacesRequest",
         "RemoveFulfillmentPlacesMetadata",
         "RemoveFulfillmentPlacesResponse",
@@ -73,9 +80,19 @@ class CreateProductRequest(proto.Message):
             error is returned.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    product = proto.Field(proto.MESSAGE, number=2, message=gcr_product.Product,)
-    product_id = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    product = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gcr_product.Product,
+    )
+    product_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetProductRequest(proto.Message):
@@ -96,7 +113,10 @@ class GetProductRequest(proto.Message):
             does not exist, a NOT_FOUND error is returned.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateProductRequest(proto.Message):
@@ -131,11 +151,20 @@ class UpdateProductRequest(proto.Message):
             created. In this situation, ``update_mask`` is ignored.
     """
 
-    product = proto.Field(proto.MESSAGE, number=1, message=gcr_product.Product,)
+    product = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gcr_product.Product,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    allow_missing = proto.Field(
+        proto.BOOL,
+        number=3,
     )
-    allow_missing = proto.Field(proto.BOOL, number=3,)
 
 
 class DeleteProductRequest(proto.Message):
@@ -168,7 +197,10 @@ class DeleteProductRequest(proto.Message):
             [Product][google.cloud.retail.v2.Product] will be deleted.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListProductsRequest(proto.Message):
@@ -258,11 +290,27 @@ class ListProductsRequest(proto.Message):
             INVALID_ARGUMENT error is returned.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    read_mask = proto.Field(proto.MESSAGE, number=5, message=field_mask_pb2.FieldMask,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    read_mask = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=field_mask_pb2.FieldMask,
+    )
 
 
 class ListProductsResponse(proto.Message):
@@ -285,9 +333,14 @@ class ListProductsResponse(proto.Message):
         return self
 
     products = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gcr_product.Product,
+        proto.MESSAGE,
+        number=1,
+        message=gcr_product.Product,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class SetInventoryRequest(proto.Message):
@@ -325,6 +378,26 @@ class SetInventoryRequest(proto.Message):
             value for
             [SetInventoryRequest.set_time][google.cloud.retail.v2.SetInventoryRequest.set_time].
 
+            The caller can replace place IDs for a subset of fulfillment
+            types in the following ways:
+
+            -  Adds "fulfillment_info" in
+               [SetInventoryRequest.set_mask][google.cloud.retail.v2.SetInventoryRequest.set_mask]
+            -  Specifies only the desired fulfillment types and
+               corresponding place IDs to update in
+               [SetInventoryRequest.inventory.fulfillment_info][]
+
+            The caller can clear all place IDs from a subset of
+            fulfillment types in the following ways:
+
+            -  Adds "fulfillment_info" in
+               [SetInventoryRequest.set_mask][google.cloud.retail.v2.SetInventoryRequest.set_mask]
+            -  Specifies only the desired fulfillment types to clear in
+               [SetInventoryRequest.inventory.fulfillment_info][]
+            -  Checks that only the desired fulfillment info types have
+               empty
+               [SetInventoryRequest.inventory.fulfillment_info.place_ids][]
+
             The last update time is recorded for the following inventory
             fields:
 
@@ -338,9 +411,9 @@ class SetInventoryRequest(proto.Message):
             instead.
         set_mask (google.protobuf.field_mask_pb2.FieldMask):
             Indicates which inventory fields in the provided
-            [Product][google.cloud.retail.v2.Product] to update. If not
-            set or set with empty paths, all inventory fields will be
-            updated.
+            [Product][google.cloud.retail.v2.Product] to update.
+
+            At least one field must be provided.
 
             If an unsupported or unknown field is provided, an
             INVALID_ARGUMENT error is returned and the entire update
@@ -361,10 +434,25 @@ class SetInventoryRequest(proto.Message):
             [Product][google.cloud.retail.v2.Product] is not found.
     """
 
-    inventory = proto.Field(proto.MESSAGE, number=1, message=gcr_product.Product,)
-    set_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,)
-    set_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    allow_missing = proto.Field(proto.BOOL, number=4,)
+    inventory = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gcr_product.Product,
+    )
+    set_mask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    set_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    allow_missing = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
 
 
 class SetInventoryMetadata(proto.Message):
@@ -450,11 +538,27 @@ class AddFulfillmentPlacesRequest(proto.Message):
             [Product][google.cloud.retail.v2.Product] is not found.
     """
 
-    product = proto.Field(proto.STRING, number=1,)
-    type_ = proto.Field(proto.STRING, number=2,)
-    place_ids = proto.RepeatedField(proto.STRING, number=3,)
-    add_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    allow_missing = proto.Field(proto.BOOL, number=5,)
+    product = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    type_ = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    place_ids = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    add_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    allow_missing = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
 
 
 class AddFulfillmentPlacesMetadata(proto.Message):
@@ -473,6 +577,166 @@ class AddFulfillmentPlacesResponse(proto.Message):
     """
 
 
+class AddLocalInventoriesRequest(proto.Message):
+    r"""Request message for [AddLocalInventories][] method.
+
+    Attributes:
+        product (str):
+            Required. Full resource name of
+            [Product][google.cloud.retail.v2.Product], such as
+            ``projects/*/locations/global/catalogs/default_catalog/branches/default_branch/products/some_product_id``.
+
+            If the caller does not have permission to access the
+            [Product][google.cloud.retail.v2.Product], regardless of
+            whether or not it exists, a PERMISSION_DENIED error is
+            returned.
+        local_inventories (Sequence[google.cloud.retail_v2.types.LocalInventory]):
+            Required. A list of inventory information at
+            difference places. Each place is identified by
+            its place ID. At most 3000 inventories are
+            allowed per request.
+        add_mask (google.protobuf.field_mask_pb2.FieldMask):
+            Indicates which inventory fields in the provided list of
+            [LocalInventory][google.cloud.retail.v2.LocalInventory] to
+            update. The field is updated to the provided value.
+
+            If a field is set while the place does not have a previous
+            local inventory, the local inventory at that store is
+            created.
+
+            If a field is set while the value of that field is not
+            provided, the original field value, if it exists, is
+            deleted.
+
+            If the mask is not set or set with empty paths, all
+            inventory fields will be updated.
+
+            If an unsupported or unknown field is provided, an
+            INVALID_ARGUMENT error is returned and the entire update
+            will be ignored.
+        add_time (google.protobuf.timestamp_pb2.Timestamp):
+            The time when the inventory updates are
+            issued. Used to prevent out-of-order updates on
+            local inventory fields. If not provided, the
+            internal system time will be used.
+        allow_missing (bool):
+            If set to true, and the
+            [Product][google.cloud.retail.v2.Product] is not found, the
+            local inventory will still be processed and retained for at
+            most 1 day and processed once the
+            [Product][google.cloud.retail.v2.Product] is created. If set
+            to false, a NOT_FOUND error is returned if the
+            [Product][google.cloud.retail.v2.Product] is not found.
+    """
+
+    product = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    local_inventories = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=common.LocalInventory,
+    )
+    add_mask = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=field_mask_pb2.FieldMask,
+    )
+    add_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    allow_missing = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+
+
+class AddLocalInventoriesMetadata(proto.Message):
+    r"""Metadata related to the progress of the AddLocalInventories
+    operation. Currently empty because there is no meaningful metadata
+    populated from the [AddLocalInventories][] method.
+
+    """
+
+
+class AddLocalInventoriesResponse(proto.Message):
+    r"""Response of the [AddLocalInventories][] API. Currently empty because
+    there is no meaningful response populated from the
+    [AddLocalInventories][] method.
+
+    """
+
+
+class RemoveLocalInventoriesRequest(proto.Message):
+    r"""Request message for [RemoveLocalInventories][] method.
+
+    Attributes:
+        product (str):
+            Required. Full resource name of
+            [Product][google.cloud.retail.v2.Product], such as
+            ``projects/*/locations/global/catalogs/default_catalog/branches/default_branch/products/some_product_id``.
+
+            If the caller does not have permission to access the
+            [Product][google.cloud.retail.v2.Product], regardless of
+            whether or not it exists, a PERMISSION_DENIED error is
+            returned.
+        place_ids (Sequence[str]):
+            Required. A list of place IDs to have their
+            inventory deleted. At most 3000 place IDs are
+            allowed per request.
+        remove_time (google.protobuf.timestamp_pb2.Timestamp):
+            The time when the inventory deletions are
+            issued. Used to prevent out-of-order updates and
+            deletions on local inventory fields. If not
+            provided, the internal system time will be used.
+        allow_missing (bool):
+            If set to true, and the
+            [Product][google.cloud.retail.v2.Product] is not found, the
+            local inventory removal request will still be processed and
+            retained for at most 1 day and processed once the
+            [Product][google.cloud.retail.v2.Product] is created. If set
+            to false, a NOT_FOUND error is returned if the
+            [Product][google.cloud.retail.v2.Product] is not found.
+    """
+
+    product = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    place_ids = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    remove_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    allow_missing = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
+
+
+class RemoveLocalInventoriesMetadata(proto.Message):
+    r"""Metadata related to the progress of the RemoveLocalInventories
+    operation. Currently empty because there is no meaningful metadata
+    populated from the [RemoveLocalInventories][] method.
+
+    """
+
+
+class RemoveLocalInventoriesResponse(proto.Message):
+    r"""Response of the [RemoveLocalInventories][] API. Currently empty
+    because there is no meaningful response populated from the
+    [RemoveLocalInventories][] method.
+
+    """
+
+
 class RemoveFulfillmentPlacesRequest(proto.Message):
     r"""Request message for [RemoveFulfillmentPlaces][] method.
 
@@ -535,11 +799,27 @@ class RemoveFulfillmentPlacesRequest(proto.Message):
             [Product][google.cloud.retail.v2.Product] is not found.
     """
 
-    product = proto.Field(proto.STRING, number=1,)
-    type_ = proto.Field(proto.STRING, number=2,)
-    place_ids = proto.RepeatedField(proto.STRING, number=3,)
-    remove_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    allow_missing = proto.Field(proto.BOOL, number=5,)
+    product = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    type_ = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    place_ids = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    remove_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    allow_missing = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
 
 
 class RemoveFulfillmentPlacesMetadata(proto.Message):
