@@ -18,7 +18,11 @@ import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.retail.v2",
-    manifest={"PurgeMetadata", "PurgeUserEventsRequest", "PurgeUserEventsResponse",},
+    manifest={
+        "PurgeMetadata",
+        "PurgeUserEventsRequest",
+        "PurgeUserEventsResponse",
+    },
 )
 
 
@@ -69,9 +73,18 @@ class PurgeUserEventsRequest(proto.Message):
             deleting any user events.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    force = proto.Field(proto.BOOL, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    force = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
 
 
 class PurgeUserEventsResponse(proto.Message):
@@ -85,7 +98,10 @@ class PurgeUserEventsResponse(proto.Message):
             of the operation.
     """
 
-    purged_events_count = proto.Field(proto.INT64, number=1,)
+    purged_events_count = proto.Field(
+        proto.INT64,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
