@@ -22,7 +22,11 @@ from google.protobuf import struct_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
-    package="google.cloud.retail.v2", manifest={"SearchRequest", "SearchResponse",},
+    package="google.cloud.retail.v2",
+    manifest={
+        "SearchRequest",
+        "SearchResponse",
+    },
 )
 
 
@@ -35,7 +39,7 @@ class SearchRequest(proto.Message):
         placement (str):
             Required. The resource name of the search engine placement,
             such as
-            ``projects/*/locations/global/catalogs/default_catalog/placements/default_search``.
+            ``projects/*/locations/global/catalogs/default_catalog/placements/default_search``
             This field is used to identify the serving configuration
             name and the set of models that will be used to make the
             search.
@@ -54,6 +58,9 @@ class SearchRequest(proto.Message):
             single device. This unique identifier should not change if
             the visitor logs in or out of the website.
 
+            This should be the same identifier as
+            [UserEvent.visitor_id][google.cloud.retail.v2.UserEvent.visitor_id].
+
             The field must be a UTF-8 encoded string with a length limit
             of 128 characters. Otherwise, an INVALID_ARGUMENT error is
             returned.
@@ -97,6 +104,9 @@ class SearchRequest(proto.Message):
             If this field is unrecognizable, an INVALID_ARGUMENT is
             returned.
         canonical_filter (str):
+            The default filter that is applied when a user performs a
+            search without checking any filters on the search page.
+
             The filter applied to every search request when quality
             improvement such as query expansion is needed. For example,
             if a query does not have enough results, an expanded query
@@ -126,12 +136,12 @@ class SearchRequest(proto.Message):
             A maximum of 100 values are allowed. Otherwise, an
             INVALID_ARGUMENT error is returned.
         dynamic_facet_spec (google.cloud.retail_v2.types.SearchRequest.DynamicFacetSpec):
+            Deprecated. Refer to
+            https://cloud.google.com/retail/docs/configs#dynamic
+            to enable dynamic facets. Do not set this field.
             The specification for dynamically generated
             facets. Notice that only textual facets can be
             dynamically generated.
-            This feature requires additional allowlisting.
-            Contact Retail Search support team if you are
-            interested in using dynamic facet feature.
         boost_spec (google.cloud.retail_v2.types.SearchRequest.BoostSpec):
             Boost specification to boost certain products. See more
             details at this `user
@@ -151,14 +161,15 @@ class SearchRequest(proto.Message):
         variant_rollup_keys (Sequence[str]):
             The keys to fetch and rollup the matching
             [variant][google.cloud.retail.v2.Product.Type.VARIANT]
-            [Product][google.cloud.retail.v2.Product]s attributes. The
-            attributes from all the matching
+            [Product][google.cloud.retail.v2.Product]s attributes,
+            [FulfillmentInfo][google.cloud.retail.v2.FulfillmentInfo] or
+            [LocalInventory][google.cloud.retail.v2.LocalInventory]s
+            attributes. The attributes from all the matching
             [variant][google.cloud.retail.v2.Product.Type.VARIANT]
-            [Product][google.cloud.retail.v2.Product]s are merged and
-            de-duplicated. Notice that rollup
-            [variant][google.cloud.retail.v2.Product.Type.VARIANT]
-            [Product][google.cloud.retail.v2.Product]s attributes will
-            lead to extra query latency. Maximum number of keys is 10.
+            [Product][google.cloud.retail.v2.Product]s or
+            [LocalInventory][google.cloud.retail.v2.LocalInventory]s are
+            merged and de-duplicated. Notice that rollup attributes will
+            lead to extra query latency. Maximum number of keys is 30.
 
             For
             [FulfillmentInfo][google.cloud.retail.v2.FulfillmentInfo], a
@@ -175,6 +186,7 @@ class SearchRequest(proto.Message):
             -  discount
             -  variantId
             -  inventory(place_id,price)
+            -  inventory(place_id,original_price)
             -  inventory(place_id,attributes.key), where key is any key
                in the [Product.inventories.attributes][] map.
             -  attributes.key, where key is any key in the
@@ -246,6 +258,8 @@ class SearchRequest(proto.Message):
             The search mode of the search request. If not
             specified, a single search request triggers both
             product search and faceted search.
+        personalization_spec (google.cloud.retail_v2.types.SearchRequest.PersonalizationSpec):
+            The specification for personalization.
     """
 
     class SearchMode(proto.Enum):
@@ -370,6 +384,7 @@ class SearchRequest(proto.Message):
                        -  "ratingCount"
                        -  "attributes.key"
                        -  "inventory(place_id,price)"
+                       -  "inventory(place_id,original_price)"
                        -  "inventory(place_id,attributes.key)".
                 intervals (Sequence[google.cloud.retail_v2.types.Interval]):
                     Set only if values should be bucketized into
@@ -463,22 +478,53 @@ class SearchRequest(proto.Message):
                     both in stock and ship to store "123".
             """
 
-            key = proto.Field(proto.STRING, number=1,)
+            key = proto.Field(
+                proto.STRING,
+                number=1,
+            )
             intervals = proto.RepeatedField(
-                proto.MESSAGE, number=2, message=common.Interval,
+                proto.MESSAGE,
+                number=2,
+                message=common.Interval,
+            )
+            restricted_values = proto.RepeatedField(
+                proto.STRING,
+                number=3,
+            )
+            prefixes = proto.RepeatedField(
+                proto.STRING,
+                number=8,
+            )
+            contains = proto.RepeatedField(
+                proto.STRING,
+                number=9,
+            )
+            order_by = proto.Field(
+                proto.STRING,
+                number=4,
+            )
+            query = proto.Field(
+                proto.STRING,
+                number=5,
             )
-            restricted_values = proto.RepeatedField(proto.STRING, number=3,)
-            prefixes = proto.RepeatedField(proto.STRING, number=8,)
-            contains = proto.RepeatedField(proto.STRING, number=9,)
-            order_by = proto.Field(proto.STRING, number=4,)
-            query = proto.Field(proto.STRING, number=5,)
 
         facet_key = proto.Field(
-            proto.MESSAGE, number=1, message="SearchRequest.FacetSpec.FacetKey",
+            proto.MESSAGE,
+            number=1,
+            message="SearchRequest.FacetSpec.FacetKey",
+        )
+        limit = proto.Field(
+            proto.INT32,
+            number=2,
+        )
+        excluded_filter_keys = proto.RepeatedField(
+            proto.STRING,
+            number=3,
+        )
+        enable_dynamic_position = proto.Field(
+            proto.BOOL,
+            number=4,
         )
-        limit = proto.Field(proto.INT32, number=2,)
-        excluded_filter_keys = proto.RepeatedField(proto.STRING, number=3,)
-        enable_dynamic_position = proto.Field(proto.BOOL, number=4,)
 
     class DynamicFacetSpec(proto.Message):
         r"""The specifications of dynamically generated facets.
@@ -497,7 +543,9 @@ class SearchRequest(proto.Message):
             ENABLED = 2
 
         mode = proto.Field(
-            proto.ENUM, number=1, enum="SearchRequest.DynamicFacetSpec.Mode",
+            proto.ENUM,
+            number=1,
+            enum="SearchRequest.DynamicFacetSpec.Mode",
         )
 
     class BoostSpec(proto.Message):
@@ -511,6 +559,15 @@ class SearchRequest(proto.Message):
                 specifications are all applied and combined in a
                 non-linear way. Maximum number of specifications
                 is 10.
+            skip_boost_spec_validation (bool):
+                Whether to skip boostspec validation. If this field is set
+                to true, invalid
+                [BoostSpec.condition_boost_specs][google.cloud.retail.v2.SearchRequest.BoostSpec.condition_boost_specs]
+                will be ignored and valid
+                [BoostSpec.condition_boost_specs][google.cloud.retail.v2.SearchRequest.BoostSpec.condition_boost_specs]
+                will still be applied.
+
+                This field is a member of `oneof`_ ``_skip_boost_spec_validation``.
         """
 
         class ConditionBoostSpec(proto.Message):
@@ -552,14 +609,25 @@ class SearchRequest(proto.Message):
                     condition is ignored.
             """
 
-            condition = proto.Field(proto.STRING, number=1,)
-            boost = proto.Field(proto.FLOAT, number=2,)
+            condition = proto.Field(
+                proto.STRING,
+                number=1,
+            )
+            boost = proto.Field(
+                proto.FLOAT,
+                number=2,
+            )
 
         condition_boost_specs = proto.RepeatedField(
             proto.MESSAGE,
             number=1,
             message="SearchRequest.BoostSpec.ConditionBoostSpec",
         )
+        skip_boost_spec_validation = proto.Field(
+            proto.BOOL,
+            number=2,
+            optional=True,
+        )
 
     class QueryExpansionSpec(proto.Message):
         r"""Specification to determine under which conditions query
@@ -586,32 +654,119 @@ class SearchRequest(proto.Message):
             AUTO = 3
 
         condition = proto.Field(
-            proto.ENUM, number=1, enum="SearchRequest.QueryExpansionSpec.Condition",
+            proto.ENUM,
+            number=1,
+            enum="SearchRequest.QueryExpansionSpec.Condition",
+        )
+        pin_unexpanded_results = proto.Field(
+            proto.BOOL,
+            number=2,
         )
-        pin_unexpanded_results = proto.Field(proto.BOOL, number=2,)
 
-    placement = proto.Field(proto.STRING, number=1,)
-    branch = proto.Field(proto.STRING, number=2,)
-    query = proto.Field(proto.STRING, number=3,)
-    visitor_id = proto.Field(proto.STRING, number=4,)
-    user_info = proto.Field(proto.MESSAGE, number=5, message=common.UserInfo,)
-    page_size = proto.Field(proto.INT32, number=7,)
-    page_token = proto.Field(proto.STRING, number=8,)
-    offset = proto.Field(proto.INT32, number=9,)
-    filter = proto.Field(proto.STRING, number=10,)
-    canonical_filter = proto.Field(proto.STRING, number=28,)
-    order_by = proto.Field(proto.STRING, number=11,)
-    facet_specs = proto.RepeatedField(proto.MESSAGE, number=12, message=FacetSpec,)
+    class PersonalizationSpec(proto.Message):
+        r"""The specification for personalization.
+
+        Attributes:
+            mode (google.cloud.retail_v2.types.SearchRequest.PersonalizationSpec.Mode):
+                Defaults to
+                [Mode.AUTO][google.cloud.retail.v2.SearchRequest.PersonalizationSpec.Mode.AUTO].
+        """
+
+        class Mode(proto.Enum):
+            r"""The personalization mode of each search request."""
+            MODE_UNSPECIFIED = 0
+            AUTO = 1
+            DISABLED = 2
+
+        mode = proto.Field(
+            proto.ENUM,
+            number=1,
+            enum="SearchRequest.PersonalizationSpec.Mode",
+        )
+
+    placement = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    branch = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    query = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    visitor_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    user_info = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=common.UserInfo,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=7,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+    offset = proto.Field(
+        proto.INT32,
+        number=9,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=10,
+    )
+    canonical_filter = proto.Field(
+        proto.STRING,
+        number=28,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    facet_specs = proto.RepeatedField(
+        proto.MESSAGE,
+        number=12,
+        message=FacetSpec,
+    )
     dynamic_facet_spec = proto.Field(
-        proto.MESSAGE, number=21, message=DynamicFacetSpec,
+        proto.MESSAGE,
+        number=21,
+        message=DynamicFacetSpec,
+    )
+    boost_spec = proto.Field(
+        proto.MESSAGE,
+        number=13,
+        message=BoostSpec,
     )
-    boost_spec = proto.Field(proto.MESSAGE, number=13, message=BoostSpec,)
     query_expansion_spec = proto.Field(
-        proto.MESSAGE, number=14, message=QueryExpansionSpec,
+        proto.MESSAGE,
+        number=14,
+        message=QueryExpansionSpec,
+    )
+    variant_rollup_keys = proto.RepeatedField(
+        proto.STRING,
+        number=17,
+    )
+    page_categories = proto.RepeatedField(
+        proto.STRING,
+        number=23,
+    )
+    search_mode = proto.Field(
+        proto.ENUM,
+        number=31,
+        enum=SearchMode,
+    )
+    personalization_spec = proto.Field(
+        proto.MESSAGE,
+        number=32,
+        message=PersonalizationSpec,
     )
-    variant_rollup_keys = proto.RepeatedField(proto.STRING, number=17,)
-    page_categories = proto.RepeatedField(proto.STRING, number=23,)
-    search_mode = proto.Field(proto.ENUM, number=31, enum=SearchMode,)
 
 
 class SearchResponse(proto.Message):
@@ -655,6 +810,13 @@ class SearchResponse(proto.Message):
             and
             [attribution_token][google.cloud.retail.v2.SearchResponse.attribution_token]
             will be set in the response.
+        applied_controls (Sequence[str]):
+            The fully qualified resource name of applied
+            `controls <https://cloud.google.com/retail/docs/serving-control-rules>`__.
+        invalid_condition_boost_specs (Sequence[google.cloud.retail_v2.types.SearchRequest.BoostSpec.ConditionBoostSpec]):
+            The invalid
+            [SearchRequest.BoostSpec.condition_boost_specs][google.cloud.retail.v2.SearchRequest.BoostSpec.condition_boost_specs]
+            that are not applied during serving.
     """
 
     class SearchResult(proto.Message):
@@ -738,14 +900,30 @@ class SearchResponse(proto.Message):
                 in the store "store1".
         """
 
-        id = proto.Field(proto.STRING, number=1,)
-        product = proto.Field(proto.MESSAGE, number=2, message=gcr_product.Product,)
-        matching_variant_count = proto.Field(proto.INT32, number=3,)
+        id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        product = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message=gcr_product.Product,
+        )
+        matching_variant_count = proto.Field(
+            proto.INT32,
+            number=3,
+        )
         matching_variant_fields = proto.MapField(
-            proto.STRING, proto.MESSAGE, number=4, message=field_mask_pb2.FieldMask,
+            proto.STRING,
+            proto.MESSAGE,
+            number=4,
+            message=field_mask_pb2.FieldMask,
         )
         variant_rollup_values = proto.MapField(
-            proto.STRING, proto.MESSAGE, number=5, message=struct_pb2.Value,
+            proto.STRING,
+            proto.MESSAGE,
+            number=5,
+            message=struct_pb2.Value,
         )
 
     class Facet(proto.Message):
@@ -786,17 +964,35 @@ class SearchResponse(proto.Message):
                     Number of items that have this facet value.
             """
 
-            value = proto.Field(proto.STRING, number=1, oneof="facet_value",)
+            value = proto.Field(
+                proto.STRING,
+                number=1,
+                oneof="facet_value",
+            )
             interval = proto.Field(
-                proto.MESSAGE, number=2, oneof="facet_value", message=common.Interval,
+                proto.MESSAGE,
+                number=2,
+                oneof="facet_value",
+                message=common.Interval,
+            )
+            count = proto.Field(
+                proto.INT64,
+                number=3,
             )
-            count = proto.Field(proto.INT64, number=3,)
 
-        key = proto.Field(proto.STRING, number=1,)
+        key = proto.Field(
+            proto.STRING,
+            number=1,
+        )
         values = proto.RepeatedField(
-            proto.MESSAGE, number=2, message="SearchResponse.Facet.FacetValue",
+            proto.MESSAGE,
+            number=2,
+            message="SearchResponse.Facet.FacetValue",
+        )
+        dynamic_facet = proto.Field(
+            proto.BOOL,
+            number=3,
         )
-        dynamic_facet = proto.Field(proto.BOOL, number=3,)
 
     class QueryExpansionInfo(proto.Message):
         r"""Information describing query expansion including whether
@@ -813,23 +1009,63 @@ class SearchResponse(proto.Message):
                 is set to true.
         """
 
-        expanded_query = proto.Field(proto.BOOL, number=1,)
-        pinned_result_count = proto.Field(proto.INT64, number=2,)
+        expanded_query = proto.Field(
+            proto.BOOL,
+            number=1,
+        )
+        pinned_result_count = proto.Field(
+            proto.INT64,
+            number=2,
+        )
 
     @property
     def raw_page(self):
         return self
 
-    results = proto.RepeatedField(proto.MESSAGE, number=1, message=SearchResult,)
-    facets = proto.RepeatedField(proto.MESSAGE, number=2, message=Facet,)
-    total_size = proto.Field(proto.INT32, number=3,)
-    corrected_query = proto.Field(proto.STRING, number=4,)
-    attribution_token = proto.Field(proto.STRING, number=5,)
-    next_page_token = proto.Field(proto.STRING, number=6,)
+    results = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=SearchResult,
+    )
+    facets = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=Facet,
+    )
+    total_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    corrected_query = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    attribution_token = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=6,
+    )
     query_expansion_info = proto.Field(
-        proto.MESSAGE, number=7, message=QueryExpansionInfo,
+        proto.MESSAGE,
+        number=7,
+        message=QueryExpansionInfo,
+    )
+    redirect_uri = proto.Field(
+        proto.STRING,
+        number=10,
+    )
+    applied_controls = proto.RepeatedField(
+        proto.STRING,
+        number=12,
+    )
+    invalid_condition_boost_specs = proto.RepeatedField(
+        proto.MESSAGE,
+        number=14,
+        message="SearchRequest.BoostSpec.ConditionBoostSpec",
     )
-    redirect_uri = proto.Field(proto.STRING, number=10,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
