@@ -23,7 +23,12 @@ from google.protobuf import wrappers_pb2  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.retail.v2",
-    manifest={"UserEvent", "ProductDetail", "CompletionDetail", "PurchaseTransaction",},
+    manifest={
+        "UserEvent",
+        "ProductDetail",
+        "CompletionDetail",
+        "PurchaseTransaction",
+    },
 )
 
 
@@ -38,7 +43,6 @@ class UserEvent(proto.Message):
             -  ``add-to-cart``: Products being added to cart.
             -  ``category-page-view``: Special pages such as sale or
                promotion pages viewed.
-            -  ``completion``: Completion query result showed/clicked.
             -  ``detail-page-view``: Products detail page viewed.
             -  ``home-page-view``: Homepage viewed.
             -  ``promotion-offered``: Promotion is offered to a user.
@@ -118,6 +122,7 @@ class UserEvent(proto.Message):
             -  ``add-to-cart``
             -  ``detail-page-view``
             -  ``purchase-complete``
+            -  ``search``
 
             In a ``search`` event, this field represents the products
             returned to the end user on the current page (the end user
@@ -129,25 +134,38 @@ class UserEvent(proto.Message):
             is desired. The end user may have not finished browsing the
             whole page yet.
         completion_detail (google.cloud.retail_v2.types.CompletionDetail):
-            The main completion details related to the event.
+            The main auto-completion details related to the event.
 
-            In a ``completion`` event, this field represents the
-            completions returned to the end user and the clicked
-            completion by the end user. In a ``search`` event, it
-            represents the search event happens after clicking
-            completion.
+            This field should be set for ``search`` event when
+            autocomplete function is enabled and the user clicks a
+            suggestion for search.
         attributes (Sequence[google.cloud.retail_v2.types.UserEvent.AttributesEntry]):
             Extra user event features to include in the recommendation
             model.
 
-            The key must be a UTF-8 encoded string with a length limit
-            of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is
-            returned.
+            If you provide custom attributes for ingested user events,
+            also include them in the user events that you associate with
+            prediction requests. Custom attribute formatting must be
+            consistent between imported events and events provided with
+            prediction requests. This lets the Retail API use those
+            custom attributes when training models and serving
+            predictions, which helps improve recommendation quality.
 
-            For product recommendation, an example of extra user
-            information is traffic_channel, i.e. how user arrives at the
-            site. Users can arrive at the site by coming to the site
-            directly, or coming through Google search, and etc.
+            This field needs to pass all below criteria, otherwise an
+            INVALID_ARGUMENT error is returned:
+
+            -  The key must be a UTF-8 encoded string with a length
+               limit of 5,000 characters.
+            -  For text attributes, at most 400 values are allowed.
+               Empty values are not allowed. Each value must be a UTF-8
+               encoded string with a length limit of 256 characters.
+            -  For number attributes, at most 400 values are allowed.
+
+            For product recommendations, an example of extra user
+            information is traffic_channel, which is how a user arrives
+            at the site. Users can arrive at the site by coming to the
+            site directly, coming through Google search, or in other
+            ways.
         cart_id (str):
             The ID or name of the associated shopping cart. This ID is
             used to associate multiple items added or present in the
@@ -268,34 +286,93 @@ class UserEvent(proto.Message):
             automatically.
     """
 
-    event_type = proto.Field(proto.STRING, number=1,)
-    visitor_id = proto.Field(proto.STRING, number=2,)
-    session_id = proto.Field(proto.STRING, number=21,)
-    event_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    experiment_ids = proto.RepeatedField(proto.STRING, number=4,)
-    attribution_token = proto.Field(proto.STRING, number=5,)
+    event_type = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    visitor_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    session_id = proto.Field(
+        proto.STRING,
+        number=21,
+    )
+    event_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    experiment_ids = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
+    attribution_token = proto.Field(
+        proto.STRING,
+        number=5,
+    )
     product_details = proto.RepeatedField(
-        proto.MESSAGE, number=6, message="ProductDetail",
+        proto.MESSAGE,
+        number=6,
+        message="ProductDetail",
     )
     completion_detail = proto.Field(
-        proto.MESSAGE, number=22, message="CompletionDetail",
+        proto.MESSAGE,
+        number=22,
+        message="CompletionDetail",
     )
     attributes = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=7, message=common.CustomAttribute,
+        proto.STRING,
+        proto.MESSAGE,
+        number=7,
+        message=common.CustomAttribute,
+    )
+    cart_id = proto.Field(
+        proto.STRING,
+        number=8,
     )
-    cart_id = proto.Field(proto.STRING, number=8,)
     purchase_transaction = proto.Field(
-        proto.MESSAGE, number=9, message="PurchaseTransaction",
+        proto.MESSAGE,
+        number=9,
+        message="PurchaseTransaction",
+    )
+    search_query = proto.Field(
+        proto.STRING,
+        number=10,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=16,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=17,
+    )
+    offset = proto.Field(
+        proto.INT32,
+        number=18,
+    )
+    page_categories = proto.RepeatedField(
+        proto.STRING,
+        number=11,
+    )
+    user_info = proto.Field(
+        proto.MESSAGE,
+        number=12,
+        message=common.UserInfo,
+    )
+    uri = proto.Field(
+        proto.STRING,
+        number=13,
+    )
+    referrer_uri = proto.Field(
+        proto.STRING,
+        number=14,
+    )
+    page_view_id = proto.Field(
+        proto.STRING,
+        number=15,
     )
-    search_query = proto.Field(proto.STRING, number=10,)
-    filter = proto.Field(proto.STRING, number=16,)
-    order_by = proto.Field(proto.STRING, number=17,)
-    offset = proto.Field(proto.INT32, number=18,)
-    page_categories = proto.RepeatedField(proto.STRING, number=11,)
-    user_info = proto.Field(proto.MESSAGE, number=12, message=common.UserInfo,)
-    uri = proto.Field(proto.STRING, number=13,)
-    referrer_uri = proto.Field(proto.STRING, number=14,)
-    page_view_id = proto.Field(proto.STRING, number=15,)
 
 
 class ProductDetail(proto.Message):
@@ -330,8 +407,16 @@ class ProductDetail(proto.Message):
             types.
     """
 
-    product = proto.Field(proto.MESSAGE, number=1, message=gcr_product.Product,)
-    quantity = proto.Field(proto.MESSAGE, number=2, message=wrappers_pb2.Int32Value,)
+    product = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gcr_product.Product,
+    )
+    quantity = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=wrappers_pb2.Int32Value,
+    )
 
 
 class CompletionDetail(proto.Message):
@@ -351,9 +436,18 @@ class CompletionDetail(proto.Message):
             position, starting from 0.
     """
 
-    completion_attribution_token = proto.Field(proto.STRING, number=1,)
-    selected_suggestion = proto.Field(proto.STRING, number=2,)
-    selected_position = proto.Field(proto.INT32, number=3,)
+    completion_attribution_token = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    selected_suggestion = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    selected_position = proto.Field(
+        proto.INT32,
+        number=3,
+    )
 
 
 class PurchaseTransaction(proto.Message):
@@ -386,11 +480,26 @@ class PurchaseTransaction(proto.Message):
             ISO-4217 code.
     """
 
-    id = proto.Field(proto.STRING, number=1,)
-    revenue = proto.Field(proto.FLOAT, number=2,)
-    tax = proto.Field(proto.FLOAT, number=3,)
-    cost = proto.Field(proto.FLOAT, number=4,)
-    currency_code = proto.Field(proto.STRING, number=5,)
+    id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    revenue = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
+    tax = proto.Field(
+        proto.FLOAT,
+        number=3,
+    )
+    cost = proto.Field(
+        proto.FLOAT,
+        number=4,
+    )
+    currency_code = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
