@@ -13,7 +13,6 @@
 # limitations under the License.
 
 import datetime
-import os
 
 import google.auth
 
@@ -21,10 +20,10 @@ from setup_cleanup import create_bucket, upload_blob
 
 project_id = google.auth.default()[1]
 timestamp_ = datetime.datetime.now().timestamp().__round__()
-bucket_name = os.environ["EVENTS_BUCKET_NAME"]
+bucket_name = f"{project_id}_events_{timestamp_}"
 
 create_bucket(bucket_name)
 upload_blob(bucket_name, "../resources/user_events.json")
 upload_blob(bucket_name, "../resources/user_events_some_invalid.json")
 
-print("\nThe gcs bucket {} was created".format(bucket_name))
+print(f"\nThe gcs bucket {bucket_name} was created")
