@@ -89,7 +89,11 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [CatalogServiceClient, CatalogServiceAsyncClient,]
+    "client_class",
+    [
+        CatalogServiceClient,
+        CatalogServiceAsyncClient,
+    ],
 )
 def test_catalog_service_client_from_service_account_info(client_class):
     creds = ga_credentials.AnonymousCredentials()
@@ -131,7 +135,11 @@ def test_catalog_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [CatalogServiceClient, CatalogServiceAsyncClient,]
+    "client_class",
+    [
+        CatalogServiceClient,
+        CatalogServiceAsyncClient,
+    ],
 )
 def test_catalog_service_client_from_service_account_file(client_class):
     creds = ga_credentials.AnonymousCredentials()
@@ -495,7 +503,9 @@ def test_catalog_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -635,10 +645,17 @@ def test_catalog_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [catalog_service.ListCatalogsRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        catalog_service.ListCatalogsRequest,
+        dict,
+    ],
+)
 def test_list_catalogs(request_type, transport: str = "grpc"):
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -667,7 +684,8 @@ def test_list_catalogs_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -683,7 +701,8 @@ async def test_list_catalogs_async(
     transport: str = "grpc_asyncio", request_type=catalog_service.ListCatalogsRequest
 ):
     client = CatalogServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -716,7 +735,9 @@ async def test_list_catalogs_async_from_dict():
 
 
 def test_list_catalogs_field_headers():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -736,7 +757,10 @@ def test_list_catalogs_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -765,11 +789,16 @@ async def test_list_catalogs_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 def test_list_catalogs_flattened():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_catalogs), "__call__") as call:
@@ -777,7 +806,9 @@ def test_list_catalogs_flattened():
         call.return_value = catalog_service.ListCatalogsResponse()
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.list_catalogs(parent="parent_value",)
+        client.list_catalogs(
+            parent="parent_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -789,13 +820,16 @@ def test_list_catalogs_flattened():
 
 
 def test_list_catalogs_flattened_error():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         client.list_catalogs(
-            catalog_service.ListCatalogsRequest(), parent="parent_value",
+            catalog_service.ListCatalogsRequest(),
+            parent="parent_value",
         )
 
 
@@ -815,7 +849,9 @@ async def test_list_catalogs_flattened_async():
         )
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.list_catalogs(parent="parent_value",)
+        response = await client.list_catalogs(
+            parent="parent_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -836,13 +872,15 @@ async def test_list_catalogs_flattened_error_async():
     # fields is an error.
     with pytest.raises(ValueError):
         await client.list_catalogs(
-            catalog_service.ListCatalogsRequest(), parent="parent_value",
+            catalog_service.ListCatalogsRequest(),
+            parent="parent_value",
         )
 
 
 def test_list_catalogs_pager(transport_name: str = "grpc"):
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -850,15 +888,28 @@ def test_list_catalogs_pager(transport_name: str = "grpc"):
         # Set the response to a series of pages.
         call.side_effect = (
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(), catalog.Catalog(), catalog.Catalog(),],
+                catalogs=[
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                ],
                 next_page_token="abc",
             ),
-            catalog_service.ListCatalogsResponse(catalogs=[], next_page_token="def",),
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(),], next_page_token="ghi",
+                catalogs=[],
+                next_page_token="def",
             ),
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(), catalog.Catalog(),],
+                catalogs=[
+                    catalog.Catalog(),
+                ],
+                next_page_token="ghi",
+            ),
+            catalog_service.ListCatalogsResponse(
+                catalogs=[
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                ],
             ),
             RuntimeError,
         )
@@ -878,7 +929,8 @@ def test_list_catalogs_pager(transport_name: str = "grpc"):
 
 def test_list_catalogs_pages(transport_name: str = "grpc"):
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -886,15 +938,28 @@ def test_list_catalogs_pages(transport_name: str = "grpc"):
         # Set the response to a series of pages.
         call.side_effect = (
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(), catalog.Catalog(), catalog.Catalog(),],
+                catalogs=[
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                ],
                 next_page_token="abc",
             ),
-            catalog_service.ListCatalogsResponse(catalogs=[], next_page_token="def",),
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(),], next_page_token="ghi",
+                catalogs=[],
+                next_page_token="def",
             ),
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(), catalog.Catalog(),],
+                catalogs=[
+                    catalog.Catalog(),
+                ],
+                next_page_token="ghi",
+            ),
+            catalog_service.ListCatalogsResponse(
+                catalogs=[
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                ],
             ),
             RuntimeError,
         )
@@ -905,7 +970,9 @@ def test_list_catalogs_pages(transport_name: str = "grpc"):
 
 @pytest.mark.asyncio
 async def test_list_catalogs_async_pager():
-    client = CatalogServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = CatalogServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -914,19 +981,34 @@ async def test_list_catalogs_async_pager():
         # Set the response to a series of pages.
         call.side_effect = (
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(), catalog.Catalog(), catalog.Catalog(),],
+                catalogs=[
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                ],
                 next_page_token="abc",
             ),
-            catalog_service.ListCatalogsResponse(catalogs=[], next_page_token="def",),
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(),], next_page_token="ghi",
+                catalogs=[],
+                next_page_token="def",
             ),
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(), catalog.Catalog(),],
+                catalogs=[
+                    catalog.Catalog(),
+                ],
+                next_page_token="ghi",
+            ),
+            catalog_service.ListCatalogsResponse(
+                catalogs=[
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                ],
             ),
             RuntimeError,
         )
-        async_pager = await client.list_catalogs(request={},)
+        async_pager = await client.list_catalogs(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
         async for response in async_pager:
@@ -938,7 +1020,9 @@ async def test_list_catalogs_async_pager():
 
 @pytest.mark.asyncio
 async def test_list_catalogs_async_pages():
-    client = CatalogServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = CatalogServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -947,15 +1031,28 @@ async def test_list_catalogs_async_pages():
         # Set the response to a series of pages.
         call.side_effect = (
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(), catalog.Catalog(), catalog.Catalog(),],
+                catalogs=[
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                ],
                 next_page_token="abc",
             ),
-            catalog_service.ListCatalogsResponse(catalogs=[], next_page_token="def",),
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(),], next_page_token="ghi",
+                catalogs=[],
+                next_page_token="def",
             ),
             catalog_service.ListCatalogsResponse(
-                catalogs=[catalog.Catalog(), catalog.Catalog(),],
+                catalogs=[
+                    catalog.Catalog(),
+                ],
+                next_page_token="ghi",
+            ),
+            catalog_service.ListCatalogsResponse(
+                catalogs=[
+                    catalog.Catalog(),
+                    catalog.Catalog(),
+                ],
             ),
             RuntimeError,
         )
@@ -966,10 +1063,17 @@ async def test_list_catalogs_async_pages():
             assert page_.raw_page.next_page_token == token
 
 
-@pytest.mark.parametrize("request_type", [catalog_service.UpdateCatalogRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        catalog_service.UpdateCatalogRequest,
+        dict,
+    ],
+)
 def test_update_catalog(request_type, transport: str = "grpc"):
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -980,7 +1084,8 @@ def test_update_catalog(request_type, transport: str = "grpc"):
     with mock.patch.object(type(client.transport.update_catalog), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = gcr_catalog.Catalog(
-            name="name_value", display_name="display_name_value",
+            name="name_value",
+            display_name="display_name_value",
         )
         response = client.update_catalog(request)
 
@@ -999,7 +1104,8 @@ def test_update_catalog_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1015,7 +1121,8 @@ async def test_update_catalog_async(
     transport: str = "grpc_asyncio", request_type=catalog_service.UpdateCatalogRequest
 ):
     client = CatalogServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1026,7 +1133,10 @@ async def test_update_catalog_async(
     with mock.patch.object(type(client.transport.update_catalog), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            gcr_catalog.Catalog(name="name_value", display_name="display_name_value",)
+            gcr_catalog.Catalog(
+                name="name_value",
+                display_name="display_name_value",
+            )
         )
         response = await client.update_catalog(request)
 
@@ -1047,7 +1157,9 @@ async def test_update_catalog_async_from_dict():
 
 
 def test_update_catalog_field_headers():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -1067,9 +1179,10 @@ def test_update_catalog_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "catalog.name=catalog.name/value",) in kw[
-        "metadata"
-    ]
+    assert (
+        "x-goog-request-params",
+        "catalog.name=catalog.name/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1096,13 +1209,16 @@ async def test_update_catalog_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "catalog.name=catalog.name/value",) in kw[
-        "metadata"
-    ]
+    assert (
+        "x-goog-request-params",
+        "catalog.name=catalog.name/value",
+    ) in kw["metadata"]
 
 
 def test_update_catalog_flattened():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.update_catalog), "__call__") as call:
@@ -1128,7 +1244,9 @@ def test_update_catalog_flattened():
 
 
 def test_update_catalog_flattened_error():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1188,11 +1306,16 @@ async def test_update_catalog_flattened_error_async():
 
 
 @pytest.mark.parametrize(
-    "request_type", [catalog_service.SetDefaultBranchRequest, dict,]
+    "request_type",
+    [
+        catalog_service.SetDefaultBranchRequest,
+        dict,
+    ],
 )
 def test_set_default_branch(request_type, transport: str = "grpc"):
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1220,7 +1343,8 @@ def test_set_default_branch_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1239,7 +1363,8 @@ async def test_set_default_branch_async(
     request_type=catalog_service.SetDefaultBranchRequest,
 ):
     client = CatalogServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1269,7 +1394,9 @@ async def test_set_default_branch_async_from_dict():
 
 
 def test_set_default_branch_field_headers():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -1291,7 +1418,10 @@ def test_set_default_branch_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "catalog=catalog/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "catalog=catalog/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1320,11 +1450,16 @@ async def test_set_default_branch_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "catalog=catalog/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "catalog=catalog/value",
+    ) in kw["metadata"]
 
 
 def test_set_default_branch_flattened():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1334,7 +1469,9 @@ def test_set_default_branch_flattened():
         call.return_value = None
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.set_default_branch(catalog="catalog_value",)
+        client.set_default_branch(
+            catalog="catalog_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1346,13 +1483,16 @@ def test_set_default_branch_flattened():
 
 
 def test_set_default_branch_flattened_error():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         client.set_default_branch(
-            catalog_service.SetDefaultBranchRequest(), catalog="catalog_value",
+            catalog_service.SetDefaultBranchRequest(),
+            catalog="catalog_value",
         )
 
 
@@ -1372,7 +1512,9 @@ async def test_set_default_branch_flattened_async():
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(None)
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.set_default_branch(catalog="catalog_value",)
+        response = await client.set_default_branch(
+            catalog="catalog_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1393,16 +1535,22 @@ async def test_set_default_branch_flattened_error_async():
     # fields is an error.
     with pytest.raises(ValueError):
         await client.set_default_branch(
-            catalog_service.SetDefaultBranchRequest(), catalog="catalog_value",
+            catalog_service.SetDefaultBranchRequest(),
+            catalog="catalog_value",
         )
 
 
 @pytest.mark.parametrize(
-    "request_type", [catalog_service.GetDefaultBranchRequest, dict,]
+    "request_type",
+    [
+        catalog_service.GetDefaultBranchRequest,
+        dict,
+    ],
 )
 def test_get_default_branch(request_type, transport: str = "grpc"):
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1415,7 +1563,8 @@ def test_get_default_branch(request_type, transport: str = "grpc"):
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = catalog_service.GetDefaultBranchResponse(
-            branch="branch_value", note="note_value",
+            branch="branch_value",
+            note="note_value",
         )
         response = client.get_default_branch(request)
 
@@ -1434,7 +1583,8 @@ def test_get_default_branch_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = CatalogServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1453,7 +1603,8 @@ async def test_get_default_branch_async(
     request_type=catalog_service.GetDefaultBranchRequest,
 ):
     client = CatalogServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1467,7 +1618,8 @@ async def test_get_default_branch_async(
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             catalog_service.GetDefaultBranchResponse(
-                branch="branch_value", note="note_value",
+                branch="branch_value",
+                note="note_value",
             )
         )
         response = await client.get_default_branch(request)
@@ -1489,7 +1641,9 @@ async def test_get_default_branch_async_from_dict():
 
 
 def test_get_default_branch_field_headers():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -1511,7 +1665,10 @@ def test_get_default_branch_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "catalog=catalog/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "catalog=catalog/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1542,11 +1699,16 @@ async def test_get_default_branch_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "catalog=catalog/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "catalog=catalog/value",
+    ) in kw["metadata"]
 
 
 def test_get_default_branch_flattened():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1556,7 +1718,9 @@ def test_get_default_branch_flattened():
         call.return_value = catalog_service.GetDefaultBranchResponse()
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.get_default_branch(catalog="catalog_value",)
+        client.get_default_branch(
+            catalog="catalog_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1568,13 +1732,16 @@ def test_get_default_branch_flattened():
 
 
 def test_get_default_branch_flattened_error():
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         client.get_default_branch(
-            catalog_service.GetDefaultBranchRequest(), catalog="catalog_value",
+            catalog_service.GetDefaultBranchRequest(),
+            catalog="catalog_value",
         )
 
 
@@ -1596,7 +1763,9 @@ async def test_get_default_branch_flattened_async():
         )
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.get_default_branch(catalog="catalog_value",)
+        response = await client.get_default_branch(
+            catalog="catalog_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1617,7 +1786,8 @@ async def test_get_default_branch_flattened_error_async():
     # fields is an error.
     with pytest.raises(ValueError):
         await client.get_default_branch(
-            catalog_service.GetDefaultBranchRequest(), catalog="catalog_value",
+            catalog_service.GetDefaultBranchRequest(),
+            catalog="catalog_value",
         )
 
 
@@ -1628,7 +1798,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = CatalogServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1648,7 +1819,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = CatalogServiceClient(client_options=options, transport=transport,)
+        client = CatalogServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1664,7 +1838,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = CatalogServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1709,8 +1884,13 @@ def test_transport_adc(transport_class):
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = CatalogServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.CatalogServiceGrpcTransport,)
+    client = CatalogServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.CatalogServiceGrpcTransport,
+    )
 
 
 def test_catalog_service_base_transport_error():
@@ -1758,7 +1938,8 @@ def test_catalog_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.CatalogServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1916,7 +2097,8 @@ def test_catalog_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.CatalogServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1928,7 +2110,8 @@ def test_catalog_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.CatalogServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -2041,7 +2224,10 @@ def test_branch_path():
     catalog = "whelk"
     branch = "octopus"
     expected = "projects/{project}/locations/{location}/catalogs/{catalog}/branches/{branch}".format(
-        project=project, location=location, catalog=catalog, branch=branch,
+        project=project,
+        location=location,
+        catalog=catalog,
+        branch=branch,
     )
     actual = CatalogServiceClient.branch_path(project, location, catalog, branch)
     assert expected == actual
@@ -2066,7 +2252,9 @@ def test_catalog_path():
     location = "nautilus"
     catalog = "scallop"
     expected = "projects/{project}/locations/{location}/catalogs/{catalog}".format(
-        project=project, location=location, catalog=catalog,
+        project=project,
+        location=location,
+        catalog=catalog,
     )
     actual = CatalogServiceClient.catalog_path(project, location, catalog)
     assert expected == actual
@@ -2107,7 +2295,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "oyster"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = CatalogServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -2125,7 +2315,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "cuttlefish"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = CatalogServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -2143,7 +2335,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "winkle"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = CatalogServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -2163,7 +2357,8 @@ def test_common_location_path():
     project = "scallop"
     location = "abalone"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = CatalogServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -2188,7 +2383,8 @@ def test_client_with_default_client_info():
         transports.CatalogServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = CatalogServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2197,7 +2393,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = CatalogServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2205,7 +2402,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = CatalogServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
