@@ -94,7 +94,11 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [CompletionServiceClient, CompletionServiceAsyncClient,]
+    "client_class",
+    [
+        CompletionServiceClient,
+        CompletionServiceAsyncClient,
+    ],
 )
 def test_completion_service_client_from_service_account_info(client_class):
     creds = ga_credentials.AnonymousCredentials()
@@ -136,7 +140,11 @@ def test_completion_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [CompletionServiceClient, CompletionServiceAsyncClient,]
+    "client_class",
+    [
+        CompletionServiceClient,
+        CompletionServiceAsyncClient,
+    ],
 )
 def test_completion_service_client_from_service_account_file(client_class):
     creds = ga_credentials.AnonymousCredentials()
@@ -510,7 +518,9 @@ def test_completion_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -651,11 +661,16 @@ def test_completion_service_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [completion_service.CompleteQueryRequest, dict,]
+    "request_type",
+    [
+        completion_service.CompleteQueryRequest,
+        dict,
+    ],
 )
 def test_complete_query(request_type, transport: str = "grpc"):
     client = CompletionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -684,7 +699,8 @@ def test_complete_query_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = CompletionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -701,7 +717,8 @@ async def test_complete_query_async(
     request_type=completion_service.CompleteQueryRequest,
 ):
     client = CompletionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -734,7 +751,9 @@ async def test_complete_query_async_from_dict():
 
 
 def test_complete_query_field_headers():
-    client = CompletionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CompletionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -754,7 +773,10 @@ def test_complete_query_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "catalog=catalog/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "catalog=catalog/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -783,15 +805,23 @@ async def test_complete_query_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "catalog=catalog/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "catalog=catalog/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [import_config.ImportCompletionDataRequest, dict,]
+    "request_type",
+    [
+        import_config.ImportCompletionDataRequest,
+        dict,
+    ],
 )
 def test_import_completion_data(request_type, transport: str = "grpc"):
     client = CompletionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -819,7 +849,8 @@ def test_import_completion_data_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = CompletionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -838,7 +869,8 @@ async def test_import_completion_data_async(
     request_type=import_config.ImportCompletionDataRequest,
 ):
     client = CompletionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -870,7 +902,9 @@ async def test_import_completion_data_async_from_dict():
 
 
 def test_import_completion_data_field_headers():
-    client = CompletionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CompletionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -892,7 +926,10 @@ def test_import_completion_data_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -923,7 +960,10 @@ async def test_import_completion_data_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 def test_credentials_transport_error():
@@ -933,7 +973,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = CompletionServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -953,7 +994,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = CompletionServiceClient(client_options=options, transport=transport,)
+        client = CompletionServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -969,7 +1013,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = CompletionServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1014,8 +1059,13 @@ def test_transport_adc(transport_class):
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = CompletionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.CompletionServiceGrpcTransport,)
+    client = CompletionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.CompletionServiceGrpcTransport,
+    )
 
 
 def test_completion_service_base_transport_error():
@@ -1066,7 +1116,8 @@ def test_completion_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.CompletionServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1224,7 +1275,8 @@ def test_completion_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.CompletionServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1236,7 +1288,8 @@ def test_completion_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.CompletionServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1345,12 +1398,16 @@ def test_completion_service_transport_channel_mtls_with_adc(transport_class):
 
 def test_completion_service_grpc_lro_client():
     client = CompletionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1358,12 +1415,16 @@ def test_completion_service_grpc_lro_client():
 
 def test_completion_service_grpc_lro_async_client():
     client = CompletionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsAsyncClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1374,7 +1435,9 @@ def test_catalog_path():
     location = "clam"
     catalog = "whelk"
     expected = "projects/{project}/locations/{location}/catalogs/{catalog}".format(
-        project=project, location=location, catalog=catalog,
+        project=project,
+        location=location,
+        catalog=catalog,
     )
     actual = CompletionServiceClient.catalog_path(project, location, catalog)
     assert expected == actual
@@ -1415,7 +1478,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "winkle"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = CompletionServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1433,7 +1498,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "scallop"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = CompletionServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1451,7 +1518,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "squid"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = CompletionServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1471,7 +1540,8 @@ def test_common_location_path():
     project = "whelk"
     location = "octopus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = CompletionServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1496,7 +1566,8 @@ def test_client_with_default_client_info():
         transports.CompletionServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = CompletionServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1505,7 +1576,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = CompletionServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1513,7 +1585,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = CompletionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
