@@ -39,6 +39,7 @@ from google.cloud.retail_v2.services.prediction_service import transports
 from google.cloud.retail_v2.types import common
 from google.cloud.retail_v2.types import prediction_service
 from google.cloud.retail_v2.types import product
+from google.cloud.retail_v2.types import promotion
 from google.cloud.retail_v2.types import user_event
 from google.oauth2 import service_account
 from google.protobuf import duration_pb2  # type: ignore
@@ -95,7 +96,11 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [PredictionServiceClient, PredictionServiceAsyncClient,]
+    "client_class",
+    [
+        PredictionServiceClient,
+        PredictionServiceAsyncClient,
+    ],
 )
 def test_prediction_service_client_from_service_account_info(client_class):
     creds = ga_credentials.AnonymousCredentials()
@@ -137,7 +142,11 @@ def test_prediction_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [PredictionServiceClient, PredictionServiceAsyncClient,]
+    "client_class",
+    [
+        PredictionServiceClient,
+        PredictionServiceAsyncClient,
+    ],
 )
 def test_prediction_service_client_from_service_account_file(client_class):
     creds = ga_credentials.AnonymousCredentials()
@@ -511,7 +520,9 @@ def test_prediction_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -651,10 +662,17 @@ def test_prediction_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [prediction_service.PredictRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        prediction_service.PredictRequest,
+        dict,
+    ],
+)
 def test_predict(request_type, transport: str = "grpc"):
     client = PredictionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -687,7 +705,8 @@ def test_predict_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = PredictionServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -703,7 +722,8 @@ async def test_predict_async(
     transport: str = "grpc_asyncio", request_type=prediction_service.PredictRequest
 ):
     client = PredictionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -740,7 +760,9 @@ async def test_predict_async_from_dict():
 
 
 def test_predict_field_headers():
-    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -760,7 +782,10 @@ def test_predict_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "placement=placement/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "placement=placement/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -789,7 +814,10 @@ async def test_predict_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "placement=placement/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "placement=placement/value",
+    ) in kw["metadata"]
 
 
 def test_credentials_transport_error():
@@ -799,7 +827,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = PredictionServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -819,7 +848,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = PredictionServiceClient(client_options=options, transport=transport,)
+        client = PredictionServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -835,7 +867,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = PredictionServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -880,8 +913,13 @@ def test_transport_adc(transport_class):
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.PredictionServiceGrpcTransport,)
+    client = PredictionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.PredictionServiceGrpcTransport,
+    )
 
 
 def test_prediction_service_base_transport_error():
@@ -924,7 +962,8 @@ def test_prediction_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.PredictionServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1082,7 +1121,8 @@ def test_prediction_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.PredictionServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1094,7 +1134,8 @@ def test_prediction_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.PredictionServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1257,7 +1298,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "squid"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = PredictionServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1275,7 +1318,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "whelk"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = PredictionServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1293,7 +1338,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "oyster"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = PredictionServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1313,7 +1360,8 @@ def test_common_location_path():
     project = "cuttlefish"
     location = "mussel"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = PredictionServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1338,7 +1386,8 @@ def test_client_with_default_client_info():
         transports.PredictionServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = PredictionServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1347,7 +1396,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = PredictionServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1355,7 +1405,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = PredictionServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
