@@ -44,6 +44,7 @@ from google.cloud.retail_v2.services.user_event_service import transports
 from google.cloud.retail_v2.types import common
 from google.cloud.retail_v2.types import import_config
 from google.cloud.retail_v2.types import product
+from google.cloud.retail_v2.types import promotion
 from google.cloud.retail_v2.types import purge_config
 from google.cloud.retail_v2.types import user_event
 from google.cloud.retail_v2.types import user_event_service
@@ -104,7 +105,11 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [UserEventServiceClient, UserEventServiceAsyncClient,]
+    "client_class",
+    [
+        UserEventServiceClient,
+        UserEventServiceAsyncClient,
+    ],
 )
 def test_user_event_service_client_from_service_account_info(client_class):
     creds = ga_credentials.AnonymousCredentials()
@@ -146,7 +151,11 @@ def test_user_event_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [UserEventServiceClient, UserEventServiceAsyncClient,]
+    "client_class",
+    [
+        UserEventServiceClient,
+        UserEventServiceAsyncClient,
+    ],
 )
 def test_user_event_service_client_from_service_account_file(client_class):
     creds = ga_credentials.AnonymousCredentials()
@@ -520,7 +529,9 @@ def test_user_event_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -661,11 +672,16 @@ def test_user_event_service_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [user_event_service.WriteUserEventRequest, dict,]
+    "request_type",
+    [
+        user_event_service.WriteUserEventRequest,
+        dict,
+    ],
 )
 def test_write_user_event(request_type, transport: str = "grpc"):
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -720,7 +736,8 @@ def test_write_user_event_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -737,7 +754,8 @@ async def test_write_user_event_async(
     request_type=user_event_service.WriteUserEventRequest,
 ):
     client = UserEventServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -796,7 +814,9 @@ async def test_write_user_event_async_from_dict():
 
 
 def test_write_user_event_field_headers():
-    client = UserEventServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = UserEventServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -816,7 +836,10 @@ def test_write_user_event_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -845,15 +868,23 @@ async def test_write_user_event_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [user_event_service.CollectUserEventRequest, dict,]
+    "request_type",
+    [
+        user_event_service.CollectUserEventRequest,
+        dict,
+    ],
 )
 def test_collect_user_event(request_type, transport: str = "grpc"):
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -866,7 +897,8 @@ def test_collect_user_event(request_type, transport: str = "grpc"):
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = httpbody_pb2.HttpBody(
-            content_type="content_type_value", data=b"data_blob",
+            content_type="content_type_value",
+            data=b"data_blob",
         )
         response = client.collect_user_event(request)
 
@@ -885,7 +917,8 @@ def test_collect_user_event_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -904,7 +937,8 @@ async def test_collect_user_event_async(
     request_type=user_event_service.CollectUserEventRequest,
 ):
     client = UserEventServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -917,7 +951,10 @@ async def test_collect_user_event_async(
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            httpbody_pb2.HttpBody(content_type="content_type_value", data=b"data_blob",)
+            httpbody_pb2.HttpBody(
+                content_type="content_type_value",
+                data=b"data_blob",
+            )
         )
         response = await client.collect_user_event(request)
 
@@ -938,7 +975,9 @@ async def test_collect_user_event_async_from_dict():
 
 
 def test_collect_user_event_field_headers():
-    client = UserEventServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = UserEventServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -960,7 +999,10 @@ def test_collect_user_event_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -991,13 +1033,23 @@ async def test_collect_user_event_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
-@pytest.mark.parametrize("request_type", [purge_config.PurgeUserEventsRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        purge_config.PurgeUserEventsRequest,
+        dict,
+    ],
+)
 def test_purge_user_events(request_type, transport: str = "grpc"):
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1025,7 +1077,8 @@ def test_purge_user_events_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1043,7 +1096,8 @@ async def test_purge_user_events_async(
     transport: str = "grpc_asyncio", request_type=purge_config.PurgeUserEventsRequest
 ):
     client = UserEventServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1075,7 +1129,9 @@ async def test_purge_user_events_async_from_dict():
 
 
 def test_purge_user_events_field_headers():
-    client = UserEventServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = UserEventServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -1097,7 +1153,10 @@ def test_purge_user_events_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1128,13 +1187,23 @@ async def test_purge_user_events_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
-@pytest.mark.parametrize("request_type", [import_config.ImportUserEventsRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        import_config.ImportUserEventsRequest,
+        dict,
+    ],
+)
 def test_import_user_events(request_type, transport: str = "grpc"):
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1162,7 +1231,8 @@ def test_import_user_events_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1180,7 +1250,8 @@ async def test_import_user_events_async(
     transport: str = "grpc_asyncio", request_type=import_config.ImportUserEventsRequest
 ):
     client = UserEventServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1212,7 +1283,9 @@ async def test_import_user_events_async_from_dict():
 
 
 def test_import_user_events_field_headers():
-    client = UserEventServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = UserEventServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -1234,7 +1307,10 @@ def test_import_user_events_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1265,15 +1341,23 @@ async def test_import_user_events_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [user_event_service.RejoinUserEventsRequest, dict,]
+    "request_type",
+    [
+        user_event_service.RejoinUserEventsRequest,
+        dict,
+    ],
 )
 def test_rejoin_user_events(request_type, transport: str = "grpc"):
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1301,7 +1385,8 @@ def test_rejoin_user_events_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1320,7 +1405,8 @@ async def test_rejoin_user_events_async(
     request_type=user_event_service.RejoinUserEventsRequest,
 ):
     client = UserEventServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1352,7 +1438,9 @@ async def test_rejoin_user_events_async_from_dict():
 
 
 def test_rejoin_user_events_field_headers():
-    client = UserEventServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = UserEventServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -1374,7 +1462,10 @@ def test_rejoin_user_events_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1405,7 +1496,10 @@ async def test_rejoin_user_events_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 def test_credentials_transport_error():
@@ -1415,7 +1509,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = UserEventServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1435,7 +1530,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = UserEventServiceClient(client_options=options, transport=transport,)
+        client = UserEventServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1451,7 +1549,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = UserEventServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1496,8 +1595,13 @@ def test_transport_adc(transport_class):
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = UserEventServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.UserEventServiceGrpcTransport,)
+    client = UserEventServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.UserEventServiceGrpcTransport,
+    )
 
 
 def test_user_event_service_base_transport_error():
@@ -1551,7 +1655,8 @@ def test_user_event_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.UserEventServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1709,7 +1814,8 @@ def test_user_event_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.UserEventServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1721,7 +1827,8 @@ def test_user_event_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.UserEventServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1830,12 +1937,16 @@ def test_user_event_service_transport_channel_mtls_with_adc(transport_class):
 
 def test_user_event_service_grpc_lro_client():
     client = UserEventServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1843,12 +1954,16 @@ def test_user_event_service_grpc_lro_client():
 
 def test_user_event_service_grpc_lro_async_client():
     client = UserEventServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsAsyncClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1859,7 +1974,9 @@ def test_catalog_path():
     location = "clam"
     catalog = "whelk"
     expected = "projects/{project}/locations/{location}/catalogs/{catalog}".format(
-        project=project, location=location, catalog=catalog,
+        project=project,
+        location=location,
+        catalog=catalog,
     )
     actual = UserEventServiceClient.catalog_path(project, location, catalog)
     assert expected == actual
@@ -1934,7 +2051,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "cuttlefish"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = UserEventServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1952,7 +2071,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "winkle"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = UserEventServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1970,7 +2091,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "scallop"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = UserEventServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1990,7 +2113,8 @@ def test_common_location_path():
     project = "squid"
     location = "clam"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = UserEventServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -2015,7 +2139,8 @@ def test_client_with_default_client_info():
         transports.UserEventServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = UserEventServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2024,7 +2149,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = UserEventServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2032,7 +2158,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = UserEventServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
